# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyUtilModule.Decorators as Decorators
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import UI4.FormMaster.GenericAssignParameterPolicy as GAPP_module
import PyUtilModule.Hints as Hints
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import PyFnAttribute
import PyFnGeolib
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import RenderingAPI as RenderingAPI
import UI4.FormMaster.ParameterPolicy
import Utils as Utils
import weakref
from UI4.FormMaster.ScalarParameterPolicy import ScalarParameterPolicy as ScalarParameterPolicy
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

renderer: str

class ClientIncomingValueSource(PyQt5.QtCore.QObject):
    _ClientIncomingValueSource__dummyAttr: ClassVar[PyFnAttribute.NullAttribute] = ...
    additionalUpdate: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    update: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, port: NodegraphAPI.Port, attrRoot) -> None: ...
    def _ClientIncomingValueSource__activate(self): ...
    def _ClientIncomingValueSource__computeActivationGraphState(self) -> NodegraphAPI.GraphState | None: ...
    def _ClientIncomingValueSource__deactivate(self): ...
    def _ClientIncomingValueSource__forceUpdate(self): ...
    def _ClientIncomingValueSource__getFallbackHints(self, attrPath): ...
    def _ClientIncomingValueSource__getFallbackValueAttr(self, attrPath): ...
    def _ClientIncomingValueSource__getSecondaryMergePorts(self, node: NodegraphAPI.Node): ...
    def _ClientIncomingValueSource__idle(self, *args, **kwds): ...
    def _ClientIncomingValueSource__initializeSecondaryMergeStateOps(self, txn: PyFnGeolib.GeolibRuntimeTransaction, hasSecondaryMerges: bool): ...
    def _ClientIncomingValueSource__secondaryPortsTerminalOpCallback(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, op: PyFnGeolib.GeolibRuntimeOp, txn: PyFnGeolib.GeolibRuntimeTransaction): ...
    def _ClientIncomingValueSource__terminalOpCallback(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, op, txn): ...
    def _appendToWrenchMenu(self, policy, attrPath, menu, pagePath: Incomplete | None = ...): ...
    def _closeButtonClicked(self, attrPath): ...
    def addListener(self): ...
    def delListener(self): ...
    def forceUpdate(self): ...
    def getAttrRoot(self): ...
    def getHints(self, attrPath): ...
    def getLocationAttrs(self): ...
    def getPageHints(self, attrPath, pagePath): ...
    def getPort(self) -> NodegraphAPI.Port: ...
    def getScope(self, attrPath): ...
    def getValueAttr(self, attrPath) -> PyFnAttribute.Attribute: ...
    def isCloseButtonEnabled(self, policy, attrPath): ...
    def shouldDisplayClose(self, policy, attrPath): ...
    def shouldDisplayWrench(self, policy, attrPath): ...
    def waitForReady(self): ...

class ConstraintEditPolicyDelegateGeolib3(Geolib3GenericAssignPolicyDelegate):
    def __init__(self, attrRoot, paramRoot: Incomplete | None = ...) -> None: ...
    def createPolicy(self, parentPolicy, param): ...

class Geolib3GenericAssignPolicyDelegate(UI4.FormMaster.ParameterPolicy.ParameterPolicyDelegate):
    _Geolib3GenericAssignPolicyDelegate__attrSourceCache: ClassVar[weakref.WeakValueDictionary] = ...
    def __init__(self, attrRoot, paramRoot: Incomplete | None = ...) -> None: ...
    def _setPolicyClass(self, policyClass): ...
    def createPolicy(self, parentPolicy, param, paths: type[NullValue] = ..., attributeValueSourceFactory: Incomplete | None = ...): ...
    @classmethod
    def getAttrSource(cls, port: NodegraphAPI.Port, attrRoot, attributeValueSourceFactory: Incomplete | None = ...): ...
    def getParamAttrPath(self, param): ...
    def getParamRoot(self): ...

class NullValue: ...

class OverrideGroupsPolicyDelegate(Geolib3GenericAssignPolicyDelegate):
    def createPolicy(self, parentPolicy, param): ...

class RenderOutputDefineOutputNameParameterPolicy(ScalarParameterPolicy):
    _RenderOutputDefineOutputNameParameterPolicy__help: ClassVar[str] = ...
    def __init__(self, param, parent, attrSource) -> None: ...
    def _RenderOutputDefineOutputNameParameterPolicy__sourceUpdate(self): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def getWidgetHints(self): ...

class RenderOutputDefinePolicyDelegateGeolib3(Geolib3GenericAssignPolicyDelegate):
    def createPolicy(self, parentPolicy, param): ...

class RendererProceduralArgsPolicyDelegateGeolib3(Geolib3GenericAssignPolicyDelegate):
    def createPolicy(self, parentPolicy, param, paths: type[NullValue] = ...): ...
    def getParamAttrPath(self, param): ...

def _RegisterGenericAssignType(nodeTypeName, paramRoot, attrRoot): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import CatalogAPI as CatalogAPI
import UI4.Tabs.Catalog.ImageImportDialog as ImageImportDialog
import UI4.KatanaPrefs as KatanaPrefs
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
import typing
from PyUtilModule.VirtualKatana import RenderManager as RenderManager
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from UI4.Tabs.Catalog.CatalogWidget import CatalogWidget as CatalogWidget
from typing import ClassVar, Set, Tuple

class CatalogPanel(BaseTab):
    MODE_SLOT_VIEW: ClassVar[int] = ...
    MODE_TIME_VIEW: ClassVar[int] = ...
    tabPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def _CatalogPanel__catalog_memoryUsageChanged_CB(self, eventType, eventID, **kwargs): ...
    def _CatalogPanel__doImportSequence(self): ...
    def _CatalogPanel__editMenu_aboutToShow(self): ...
    def _CatalogPanel__exportCatalogMenu_aboutToShow(self): ...
    def _CatalogPanel__lock2dCheckbox_stateChanged_CB(self, state): ...
    def _CatalogPanel__modeCapsule_valueChanged_CB(self, enabledItems, oldEnabledItems): ...
    def _CatalogPanel__populateMenuBar(self): ...
    def _CatalogPanel__renderManager_buffer2DAutoLockUpdate_CB(self, *args, **kwargs): ...
    def _CatalogPanel__saveAndPublishCatalogItem(self, catalogItems, filePathOrAssetId, extraOptions: dict = ...): ...
    def applySettings(self, settings: dict): ...
    def deleteCatalog(self, mode): ...
    def event(self, event): ...
    def exportCatalog(self, mode): ...
    def getCatalogWidget(self) -> CatalogWidget: ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar | None: ...
    def getMode(self): ...
    def getSettings(self) -> dict: ...
    def setMode(self, mode): ...

class _SyncToProjectSettingsCheckbox(PyQt5.QtWidgets.QCheckBox):
    def __init__(self, parent) -> None: ...
    def _SyncToProjectSettingsCheckbox__onPrefChanged(self, eventType: str | None, eventID: typing.Hashable, prefKey: str, prefValue: object): ...
    def _SyncToProjectSettingsCheckbox__onStateChanged(self, state): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.ExternalTools as ExternalTools
import KatanaResources as KatanaResources
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import ClassVar, Set, Tuple

class HtmlEditorWidget(PyQt5.QtWidgets.QFrame):
    _HtmlEditorWidget__pixmaps: ClassVar[dict] = ...
    kHtmlRefURL: ClassVar[str] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None, growPreview: bool = ...) -> None: ...
    def _HtmlEditorWidget__editTextChanged(self): ...
    def _HtmlEditorWidget__helpCallback(self): ...
    def _HtmlEditorWidget__insertImageCallback(self): ...
    def _HtmlEditorWidget__insertLinkCallback(self): ...
    def _HtmlEditorWidget__linkClickedCallback(self, url): ...
    def _HtmlEditorWidget__loadResources(self): ...
    def _HtmlEditorWidget__transferText(self): ...
    def getInputEditor(self): ...
    def setLocked(self, state): ...
    def setText(self, text): ...
    def text(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Manifest as Manifest, Utility as Utility
from NodeGraphView.Utility import CreateNodeAtActiveConnection as CreateNodeAtActiveConnection, FitBackdropAroundNodes as FitBackdropAroundNodes, UpdateShadingGroupConnection as UpdateShadingGroupConnection
from typing import Set, Tuple

NodeAdded: int
NodeDimmingModeConnected: int
NodeDimmingModeContributing: int
NodeDisconnected: int
NodeEdited: int
NodeUnchanged: int
NodeViewStateCount: int



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodeGraphView as NodeGraphView
import NodegraphAPI as NodegraphAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import RenderingAPI as RenderingAPI
import UI4 as UI4
import Utils as Utils
import typing
from PyUtilModule.VirtualKatana import LayeredMenuAPI as LayeredMenuAPI
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from UI4.Tabs.NodeGraphTab.Layers.BookmarkJumpMenuLayer import BookmarkJumpMenuLayer as BookmarkJumpMenuLayer
from UI4.Tabs.NodeGraphTab.Layers.CustomMenuLayer import CustomMenuLayer as CustomMenuLayer
from UI4.Tabs.NodeGraphTab.Layers.MenuLayer import MenuLayer as MenuLayer
from UI4.Tabs.NodeGraphTab.Layers.StickyNoteInteractionLayer import EditBackdropNodeDialog as EditBackdropNodeDialog
from _typeshed import Incomplete
from typing import Callable, Set, Tuple

_KeyboardShortcuts: list
g_entries: list

class CallbackTransientLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, callback, eventTrigger: Incomplete | None = ..., *args, **kwargs) -> None: ...
    def processEvent(self, event: QEvent) -> bool: ...

class NodeGraphViewInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _NodeGraphViewInteractionLayer__currentNodeViewChanged(self, previousNodeView, currentNodeView): ...
    def _NodeGraphViewInteractionLayer__deleteNodes(self, nodeList): ...
    def _NodeGraphViewInteractionLayer__getUnicodeCharacter(self, event): ...
    def _NodeGraphViewInteractionLayer__isAncestorHash(self, node: NodegraphAPI.Node, cmpHash): ...
    def _NodeGraphViewInteractionLayer__launchLayeredMenuLayer(self): ...
    def _NodeGraphViewInteractionLayer__onNetworkMaterialEditGenerated(self, _eventType, eventID, node: typing.Optional[NodegraphAPI.Node] = ...): ...
    def _NodeGraphViewInteractionLayer__onNetworkMaterialEditInvalidate(self, _eventType, eventID, invalidateAll: bool = ...): ...
    def _NodeGraphViewInteractionLayer__previewBackdropShapeAttrs(self, node: NodegraphAPI.Node, attrDict): ...
    def _NodeGraphViewInteractionLayer__processKeyPress(self, event): ...
    def _NodeGraphViewInteractionLayer__processKeyRelease(self, event): ...
    def _NodeGraphViewInteractionLayer__processMouseButtonDown(self, event): ...
    def _NodeGraphViewInteractionLayer__processMouseButtonUp(self, event): ...
    def _NodeGraphViewInteractionLayer__processMouseMove(self, event): ...
    def _NodeGraphViewInteractionLayer__processMouseWheel(self, event): ...
    def changeNodesInputConnectionsVisibility(self, nodes: list[NodegraphAPI.Node], visibiltyFunc: Callable = ..., setLocalOnly: Incomplete | None = ...): ...
    def changeSelectedNodesInputConnectionsVisibility(self, visibiltyFunc, setLocalOnly: Incomplete | None = ...): ...
    def frameSelection(self, zoom: bool = ...): ...
    def launchEditBackdropDialogCB(self, _eventName, _eventID, node: typing.Optional[NodegraphAPI.Node] = ...): ...
    def popupNodeContextMenu(self, node: NodegraphAPI.Node): ...
    def popupPortContextMenu(self, port: NodegraphAPI.Port, portCoords): ...
    def processEvent(self, event): ...
    def setLayerStack(self, layerStack): ...
    def setNodesInputConnectionsVisibility(self, nodes: list[NodegraphAPI.Node], inputConnectionsVisible: bool, setLocalOnly: Incomplete | None = ...): ...
    def setNodesViewState(self, nodes: list[NodegraphAPI.Node], viewState: int | float): ...
    def setSelectedNodesInputConnectionsVisibility(self, inputConnectionsVisible: bool, setLocalOnly: Incomplete | None = ...): ...
    def setSelectedNodesViewState(self, viewState: int | float): ...
    def showLayeredMenu(self, menu): ...
    def startDrag(self): ...
    def startNodeGraphViewDrag(self, obj: NodegraphAPI.Node | NodegraphAPI.Port) -> bool: ...
    def toggleNodesInputConnectionsVisibility(self, nodes: list[NodegraphAPI.Node], setLocalOnly: Incomplete | None = ...): ...
    def toggleSelectedNodesInputConnectionsVisibility(self, setLocalOnly: Incomplete | None = ...): ...
    def toggleShowFilterBoxState(self, nodes: list[NodegraphAPI.Node]): ...

def RegisterNodeGraphViewKeyboardShortcuts(nodegraphPanel): ...
def _OnToggleShowFilterBox(tab): ...
def _OnViewStateKeyboardShortcut(tab, viewState): ...
def _PressInputConnectionsVisibilityKeyboardShortcut(tab): ...
def _ReleaseInputConnectionsVisibilityKeyboardShortcut(tab): ...
def _getInputConnectionsVisible(node: NodegraphAPI.Node, interactionLayer): ...
def _sanitizeInputConnectionsVisible(icv): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

ARRAY_TYPE_TO_CONSTANT: list
GL_VOID_P: object
GLvoid: None
ctypes_version: list
integer_types: tuple
void: None



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class MetaCheckBox(PyQt5.QtWidgets.QCheckBox):
    toggled: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, displayName, meta, parent) -> None: ...
    def _MetaCheckBox__toggled(self, on): ...
    def getMeta(self): ...
    def mouseMoveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def mouseReleaseEvent(self, ev): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import LayeredMenuAPI as LayeredMenuAPI
import NodegraphAPI as NodegraphAPI
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import Utils as Utils
from UI4.Tabs.NodeGraphTab.Layers.TransientLayer import TransientLayer as TransientLayer
from _typeshed import Incomplete
from typing import Any, Set, Tuple

g_padb: int
g_padh: int
g_padt: int

class MenuLayer(TransientLayer):
    def __init__(self, name: Incomplete | None = ..., visible: bool = ..., interactive: bool = ..., enabled: bool = ...) -> None: ...
    def _MenuLayer__action(self): ...
    def _MenuLayer__close(self): ...
    def _MenuLayer__determineIndexOfSelectedEntry(self): ...
    def _MenuLayer__drawEntry(self, entry, i, windowSize): ...
    def _MenuLayer__fillBackground(self): ...
    def _MenuLayer__findCommonPrefix(self): ...
    def _MenuLayer__getEntrySize(self, entry): ...
    def _MenuLayer__matches(self, entry, testString): ...
    def _MenuLayer__processKeyPress(self, event): ...
    def _MenuLayer__update(self): ...
    def _createEntry(self, value: object, text: Incomplete | None = ..., color: Incomplete | None = ..., size: Incomplete | None = ..., textColor: Incomplete | None = ...) -> LayeredMenuAPI.LayeredMenuEntry: ...
    def getBottomText(self): ...
    def getChosenValue(self): ...
    def getEntries(self): ...
    def getReplacedNode(self): ...
    def onEntryChosen(self, value: object) -> Any | None: ...
    def onlyMatchWordStart(self): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def resizeGL(self): ...
    def setErrorMessage(self, errorMessage: str): ...
    def setLayerStack(self, stack): ...
    def setReplacedNode(self, replacedNode): ...
    def setReplacedNodeCallback(self, callback): ...
    def shouldSortAlphabetically(self) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from typing import Set, Tuple

def GetDragCursor(action: PyQt5.QtCore.Qt.DropAction = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtGui as QtGui
from typing import Set, Tuple

def BackspaceSpacesToTabStop(textEdit: PyQt5.QtWidgets.QTextEdit, spacing: int = ...) -> bool: ...
def CountWhitespaceToTabStop(textEdit: PyQt5.QtWidgets.QTextEdit, previousTab: bool = ..., spacing: int = ...) -> int: ...
def DeleteSpacesToTabStop(textEdit: PyQt5.QtWidgets.QTextEdit, spacing: int = ...) -> bool: ...
def InsertNewLineAndAutoIndent(textEdit: PyQt5.QtWidgets.QTextEdit, rule: str, spacing: int = ...): ...
def MoveToLineStart(textEdit: PyQt5.QtWidgets.QTextEdit, keepAnchor: bool): ...
def Reindent(textEdit: PyQt5.QtWidgets.QTextEdit, unindent: bool, spacing: int = ...): ...
def ToggleComment(textEdit: PyQt5.QtWidgets.QTextEdit, commentSymbol: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModuleCommon as EventModuleCommon
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import typing
from PyQt5.QtCore import kKatanaEventType as kKatanaEventType
from Utils.Exceptions import GetExceptionMessage as GetExceptionMessage
from typing import Set, Tuple

class KatanaEventReceiver(PyQt5.QtCore.QObject):
    def __init__(self) -> None: ...
    def _KatanaEventReceiver__invokeCollapsedDict(self, handlersDict, args): ...
    def _KatanaEventReceiver__invokeHandlerDict(self, handlersDict, eventType, eventID, kwargs): ...
    def _KatanaEventReceiver__on_collapsedEventsTimer_timeout(self): ...
    def customEvent(self, event: PyQt5.QtCore.QEvent): ...
    def initialize(self): ...
    def invokeCollapsedHandlers(self): ...

def Initialize(): ...
def ProcessAllEvents(): ...
def ProcessEvents() -> bool: ...
def PumpIdleQueue(): ...
def QueueEvent(eventType: str, eventID: typing.Hashable, priority: int = ..., **kwargs): ...
def QueuePriorityEvent(eventType: str, eventID: typing.Hashable, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class ResolutionTable:
    def __init__(self, filename: str = ...) -> None: ...
    def addEntries(self, arg0: list[ResolutionTableEntry]) -> int: ...
    def clear(self) -> None: ...
    def createResolution(self, width: int = ..., height: int = ..., name: str = ..., groupName: str = ..., pixelAspect: float = ...) -> ResolutionTableEntry: ...
    def extractValidResolutionName(self, arg0: str) -> str: ...
    def findResolution(self, width: int = ..., height: int = ..., aspect: float = ...) -> ResolutionTableEntry: ...
    def findResolutionByName(self, arg0: str) -> ResolutionTableEntry: ...
    def getEntries(self) -> list[ResolutionTableEntry]: ...
    def getEntriesForGroup(self, group: str) -> list[ResolutionTableEntry]: ...
    def getFilename(self) -> str: ...
    def getGroups(self) -> list[str]: ...
    def getResolution(self, name: str) -> ResolutionTableEntry: ...
    def hasResolution(self, name: str) -> bool: ...
    def makeResolution(self, width: int = ..., height: int = ..., aspect: float = ..., name: str = ..., fullName: str = ..., proxyName: str = ..., groupName: str = ...) -> ResolutionTableEntry: ...

class ResolutionTableEntry:
    def __init__(self, *args, **kwargs) -> None: ...
    def aspectRatio(self) -> float: ...
    def fullname(self) -> str: ...
    def groupname(self) -> str: ...
    def name(self) -> str: ...
    def proxyname(self) -> str: ...
    def xres(self) -> int: ...
    def yres(self) -> int: ...

class ResolutionTableException(Exception): ...

def Flush() -> None: ...
def GetResolutionTable(*args, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI.CatalogItem
import QT4Widgets as QT4Widgets
import Utils as Utils
from QT4Widgets.LogView import LogView
from _typeshed import Incomplete
from typing import Set, Tuple

class CatalogRenderLogWidget(LogView):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _CatalogRenderLogWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogRenderLogWidget__catalog_renderLogAppend_CB(self, eventType, eventID, item, message): ...
    def _CatalogRenderLogWidget__catalog_renderLogReset_CB(self, eventType, eventID, item): ...
    def _CatalogRenderLogWidget__renderLog_listenForMessageAppends(self, eventType, eventID, **kwargs): ...
    def getCatalogItem(self) -> CatalogAPI.CatalogItem.CatalogItem | None: ...
    def setCatalogItem(self, item): ...
    def unlockAutoScrolling(self): ...
    def updateState(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConditionalStateGrammar as ConditionalStateGrammar
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI_cmodule as Nodes3DAPI_cmodule
import PyXmlIO as PyXmlIO
import Naming as SafeIdentifier
import Naming as UniqueName
from ConditionalStateGrammar.Parser import ParseCSG as ParseCSG
from Nodes3DAPI.Node3D import Node3D as Node3D
from typing import Set, Tuple

ATTRS: str
INFO: str
META: str
TYPE: str
_ExtraHints: dict
_Parameter_XML: str

class HierarchyCreate(Node3D):
    class TreeEntry:
        def __init__(self, name, path, typeName, paramHash, children) -> None: ...
        def getUniqueChildName(self, desiredName): ...
    def __init__(self) -> None: ...
    def _HierarchyCreate__buildParameterElement(self, name, typeName, isLast): ...
    def _HierarchyCreate__getLocationTreeFromParam(self, param, parentPath: str = ...): ...
    def _HierarchyCreate__getOrBuildInfoParameter(self, group): ...
    def _HierarchyCreate__getParamForLocation(self, path): ...
    def _HierarchyCreate__getParameterByPath(self, path): ...
    def _HierarchyCreate__getTypeParameterByPath(self, path, create: bool = ...): ...
    def _HierarchyCreate__pathToParameterPath(self, path): ...
    def _HierarchyCreate__tokenizePath(self, path): ...
    def _getOpChain(self, interface): ...
    def addLocation(self, path, typeName): ...
    def addParameterHints(self, attrName, inputDict): ...
    def deleteLocation(self, path): ...
    def duplicateLocation(self, path): ...
    def getAttrsParameterForLocation(self, path, create: bool = ...): ...
    def getLocationTree(self, atLocation: str = ...): ...
    def getMetaDataParameterForLocation(self, path, create: bool = ...): ...
    def getParameterForLocation(self, path): ...
    def getTypeOfLocation(self, path): ...
    def renameLocation(self, path: str, newBaseName: str) -> str: ...
    def reorderLocation(self, path, index): ...
    def reparentLocation(self, path, newParent): ...
    def setTypeOfLocation(self, path, typeName): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.Util.ManipulatorManager as ManipulatorManager
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.NodeHints.Common2D import AddCommon2DToNodeHints as AddCommon2DToNodeHints, GetBoundsParamDict as GetBoundsParamDict
from typing import Set, Tuple

ClampOutputParamHints: dict
DownFilterParamHints: dict
GroupFilterParamHints: dict
HighlightCompensationParamHints: dict
UpFilterParamHints: dict
_NodeHints: dict
_NodeName: str



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.FWidget
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import ResourceFiles as ResourceFiles
from QT4FormWidgets.FWidget import FBoxLayout as FBoxLayout, FButton as FButton, FDisclosureTriangle as FDisclosureTriangle, FLabel as FLabel, FLockIcon as FLockIcon, FMenu as FMenu, FPixmap as FPixmap, FSpacer as FSpacer, FStateBadge as FStateBadge, FSvgIcon as FSvgIcon, FToggleStateBadge as FToggleStateBadge, FWidget as FWidget
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import Set, Tuple

class EditWrench(QT4FormWidgets.FWidget.FMenu):
    def __init__(self, parent) -> None: ...
    def fillMenu(self, menu): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import PyUtilModule.EnvUtils as EnvUtils
import NodegraphAPI.NodeNameFromParamManager as NodeNameFromParamManager
import NodegraphAPI as NodegraphAPI
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from QT4FormWidgets.ExpressionEditDialog import ExpressionEditDialog as ExpressionEditDialog
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class _NodeNameEditFrame(PyQt5.QtWidgets.QFrame):
    _NodeNameRegExp: ClassVar[PyQt5.QtCore.QRegExp] = ...
    def __init__(self, node: NodegraphAPI.Node, nameParameter: Incomplete | None = ..., usePadding: bool = ..., scale: float = ..., parent: Incomplete | None = ...) -> None: ...
    def _NodeNameEditFrame__on_lineEdit_editingAborted(self): ...
    def _NodeNameEditFrame__on_lineEdit_editingFinished(self): ...
    def mousePressEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def showEvent(self, event: PyQt5.QtGui.QShowEvent): ...

class _NodeNameLineEdit(PyQt5.QtWidgets.QLineEdit):
    editingAborted: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def contextMenuEvent(self, event): ...
    def keyPressEvent(self, event: PyQt5.QtGui.QKeyEvent): ...

def EditNodeName(node: NodegraphAPI.Node, position: Incomplete | None = ..., size: Incomplete | None = ..., bold: bool = ..., useNodeGraphStyle: bool = ..., scale: float = ..., parent: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import AssetBrowser as AssetBrowser
import CacheManager as CacheManager
import CatalogAPI as CatalogAPI
import CatalogAPI as CatalogManager
import ConfigurationAPI_cmodule as Configuration
import DrawingModule as DrawingModule
import PyFnGeolibServices.ExpressionMath as ExpressionMath
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import PyFnGeolibServices as FnGeolibServices
import GeoAPI as GeoAPI
import KatanaResources as KatanaResources
import LookFileBakeAPI as LookFileBakeAPI
import MachineInfo as MachineInfo
import MediaCacheHandler as MediaCacheHandler
import Naming as Naming
import NodeGraphView as NodeGraphView
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyOpenColorIO as OCIO
import PluginSystemAPI as PluginSystemAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyFCurve as PyFCurve
import PyXmlIO as PyXmlIO
import QT4Browser as QT4Browser
import QT4Color as QT4Color
import QT4FormWidgets as QT4FormWidgets
import QT4GLLayerStack as QT4GLLayerStack
import QT4Panels as QT4Panels
import QT4Widgets as QT4Widgets
import QTFCurve as QTFCurve
import RenderingAPI as RenderingAPI
import RerenderEventMapper as RerenderEventMapper
import PyResolutionTableFn as ResolutionTable
import KatanaResources as ResourceFiles
import UI4 as UI4
import Naming as UniqueName
import Utils as Utils
import ViewerAPI as ViewerAPI
import WorkQueue as WorkQueue
from Callbacks.Callbacks import Callbacks as Callbacks
from PyUtilModule import Initialize as Initialize
from PyUtilModule.VirtualKatana import AttrDump as AttrDump, ChildProcess as ChildProcess, ColorPaletteManager as ColorPaletteManager, Decorators as Decorators, FaceSelectionManager as FaceSelectionManager, FarmAPI as FarmAPI, FarmManager as FarmManager, FormMaster as FormMaster, Hints as Hints, IRFs as IRFs, KatanaFile as KatanaFile, LayeredMenuAPI as LayeredMenuAPI, LiveRenderAPI as LiveRenderAPI, NodeDebugOutput as NodeDebugOutput, NodeMaster as NodeMaster, NonUIPluginManager as NonUIPluginManager, OpDocumentationGenerator as OpDocumentationGenerator, ProjectSnapshot as ProjectSnapshot, Qt as Qt, QtCore as QtCore, QtGui as QtGui, QtNetwork as QtNetwork, QtOpenGL as QtOpenGL, QtSql as QtSql, QtSvg as QtSvg, QtTest as QtTest, QtWidgets as QtWidgets, QtXml as QtXml, QtXmlPatterns as QtXmlPatterns, RegisterToCamera as RegisterToCamera, RenderManager as RenderManager, RenderingCommon as RenderingCommon, ScenegraphBookmarkManager as ScenegraphBookmarkManager, ScenegraphManager as ScenegraphManager, ScenegraphUtils as ScenegraphUtils, Shelves as Shelves, SuperToolPlugins as SuperToolPlugins, UserNodes as UserNodes, Widgets as Widgets, WorkingSet as WorkingSet, WorkingSetClient as WorkingSetClient, WorkingSetManager as WorkingSetManager
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from typing import Callable, Set, Tuple

LogGLHandlersOldLevel: int
update: Callable
version: tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtGui as QtGui
import Utils as Utils
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from _typeshed import Incomplete
from typing import Set, Tuple

NODEGRAPH_DIMNONCONTRIBUTINGNODES: str
NODEGRAPH_DIMUNCONNECTEDTOVIEWNODE: str
__NODE_TYPES_PARAM_CHANGE_UPDATES_DIM: tuple

class NodeDrawingLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _NodeDrawingLayer__node_attributeEditorUpdateState_cb(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _NodeDrawingLayer__node_create_cb(self, eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...
    def _NodeDrawingLayer__node_delete_cb(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _NodeDrawingLayer__node_setBypassed_cb(self, eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...
    def _NodeDrawingLayer__node_setParent_cb(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _NodeDrawingLayer__node_setShapeAttributes_cb(self, eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...
    def _NodeDrawingLayer__node_setState_cb(self, eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...
    def _NodeDrawingLayer__node_setViewed_cb(self, eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...
    def _NodeDrawingLayer__node_thumbnailEnabled_cb(self, eventType, eventID, node: NodegraphAPI.Node, enabled, **kwargs): ...
    def _NodeDrawingLayer__node_thumbnailError_cb(self, eventType, eventID, nodeName, cacheID, **kwargs): ...
    def _NodeDrawingLayer__node_thumbnailReady_cb(self, eventType, eventID, nodeName, cacheID, image, **kwargs): ...
    def _NodeDrawingLayer__on_event_idle(self, *args, **kwargs): ...
    def _NodeDrawingLayer__on_nodegraph_loadEnd(self, eventType, eventID): ...
    def _NodeDrawingLayer__on_nodegraph_setCurrentTimeIntermediate(self, eventType: str | None, eventID: object, currentTime: float): ...
    def _NodeDrawingLayer__parameter_finalizeValue_cb(self, args): ...
    def _NodeDrawingLayer__port_setState_cb(self, eventType, eventID, **kwargs): ...
    def _NodeDrawingLayer__registerDirtyCallbacks(self, enabled): ...
    def _NodeDrawingLayer__updateNodeDimming(self): ...
    def _NodeDrawingLayer__viewMaskLinkUpdate_cb(self, args: Incomplete | None = ...): ...
    def idleUpdate(self): ...
    def paintGL(self): ...

def _nodeCanChangeGraphstate(node: Node3D) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import PyUtilModule.LiveRenderAPI as LiveRenderAPI
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyFnAttribute
import UI4 as UI4
import Utils as Utils
from typing import Set, Tuple

class ManipulatorBridge:
    def __init__(self) -> None: ...
    def _ManipulatorBridge__attrToDict(self, attrName, attr): ...
    def _ManipulatorBridge__createManipulatorPolicy(self, locationPath, attributes): ...
    def _ManipulatorBridge__getAttributeEditorAttr(self, locationPath: str) -> PyFnAttribute.GroupAttribute | None: ...
    def _ManipulatorBridge__getRootProducer(self): ...
    def _ManipulatorBridge__on_LiveAttributePolicyManager_flush(self, *args, **kwargs): ...
    def _ManipulatorBridge__requestManipulationCommitId(self): ...
    def _ManipulatorBridge__setManipulationCommitId(self, commitId): ...
    def cleanupLiveAttributes(self, locationPath: str): ...
    def closeManipulationGroup(self, locationPath): ...
    def getManipulationCommitId(self): ...
    @staticmethod
    def isNodeEditable(nodeName: str) -> bool: ...
    def openManipulationGroup(self, locationPath): ...
    def setValue(self, locationPath, attrName, attrValue, isFinal): ...
    def updateOp(self, opId: int): ...
    def __del__(self) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import Utils as Utils
from typing import Set, Tuple

class NodeBypassPolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, parent, node: NodegraphAPI.Node) -> None: ...
    def _NodeBypassPolicy__doBypassed(self, event, eventId, node: NodegraphAPI.Node, **kwargs): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def getName(self): ...
    def getType(self): ...
    def getValue(self): ...
    def getWidgetHints(self): ...
    def isLocked(self): ...
    def setValue(self, value, final: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import PyFnAttribute
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.Tabs
import Utils as Utils
import ViewerAPI
import typing
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ViewportWidget(PyQt5.QtWidgets.QOpenGLWidget):
    eventTranslators: ClassVar[dict] = ...
    singleGLContextInitialized: ClassVar[bool] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None, viewport: ViewerAPI.Viewport, name: str, postInitCallback: typing.Optional[typing.Callable] = ...) -> None: ...
    def _ViewportWidget__getLocationFromDragOrDropEvent(self, event: PyQt5.QtCore.QDragEvent | PyQt5.QtCore.QDropEvent) -> str | None: ...
    def _ViewportWidget__startDrag(self, event): ...
    def addCamera(self, cameraType: str, name: str, settings: Incomplete | None = ...) -> ViewportCamera: ...
    def addLayer(self, layerType: str, name: str) -> ViewportLayer: ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def event(self, event): ...
    def findBaseViewerTab(self) -> UI4.Tabs.BaseViewerTab | None: ...
    def getActiveCamera(self) -> ViewportCamera | None: ...
    def getCameraByIndex(self, index: int) -> ViewportCamera | None: ...
    def getCameraByName(self, name: str) -> ViewportCamera | None: ...
    def getCameraName(self, index: int) -> str | None: ...
    def getLayer(self, name: str) -> ViewportLayer | None: ...
    def getLayerByIndex(self, index: int) -> ViewportLayer | None: ...
    def getLayerName(self, index: int) -> str | None: ...
    def getName(self): ...
    def getNumberOfCameras(self) -> int: ...
    def getNumberOfLayers(self) -> int: ...
    def getOption(self, optionId: int) -> PyFnAttribute.Attribute | None: ...
    def getOptionByName(self, name: str) -> PyFnAttribute.Attribute | None: ...
    def getViewerDelegate(self) -> ViewerAPI.ViewerDelegate: ...
    def getViewport(self) -> ViewerAPI.Viewport: ...
    def initializeGL(self): ...
    def insertLayer(self, layerType: str, name: str, index: int) -> ViewportLayer: ...
    def isDirty(self): ...
    def leaveEvent(self, event): ...
    def mouseMoveEvent(self, event): ...
    def paintEngine(self): ...
    def paintGL(self): ...
    def removeCamera(self, name: str): ...
    def removeCameraByIndex(self, index: int): ...
    def removeLayer(self, name: str): ...
    def removeLayerByIndex(self, index: int): ...
    def resizeGL(self, width, height): ...
    def setActiveCamera(self, camera: ViewportCamera): ...
    def setDirty(self, dirty: bool): ...
    def setOption(self, optionId: int, attr: PyFnAttribute.Attribute): ...
    def setOptionByName(self, name: str, attr: PyFnAttribute.Attribute): ...
    def setStartDragCallback(self, callback: typing.Callable): ...
    def setUnhandledEventCallback(self, callback: typing.Callable): ...
    def setViewport(self, viewport: ViewerAPI.Viewport | None): ...
    def updateBuiltInCamerasFromProjectSettings(self): ...
    def updateCameraFromProjectSettings(self, cameraName: str, isOrthographic: bool = ...): ...
    def writeToFile(self, filepath: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtCore
import PyQt5.QtWebEngineWidgets
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from typing import ClassVar, Set, Tuple

class HelpView(PyQt5.QtWebEngineWidgets.QWebEngineView):
    DEFAULT_STYLE_SHEET_FILENAME: ClassVar[str] = ...
    DEFAULT_ZOOM_LEVEL: ClassVar[float] = ...
    MAX_ZOOM_LEVEL: ClassVar[int] = ...
    MIN_ZOOM_LEVEL: ClassVar[float] = ...
    inlineCSS: ClassVar[str] = ...
    linkClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, defaultZoomLevel: float = ...) -> None: ...
    @classmethod
    def GetUrlFromFilename(cls, filename: str) -> PyQt5.QtCore.QUrl: ...
    def _HelpView__linkHoveredCallback(self, url): ...
    def _HelpView__resetZoomLevel(self): ...
    def backwardTo(self, index: int): ...
    def event(self, event): ...
    def eventFilter(self, obj, event): ...
    def forwardTo(self, index: int): ...
    def setBody(self, body: str): ...
    def zoomIn(self, increment: float = ...): ...
    def zoomOut(self, decrement: float = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtGui
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import UI4 as UI4
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from typing import ClassVar, Set, Tuple

g_threshold: float

class NodeOverlayLayer(QT4GLLayerStack.LayerStack.Layer):
    _NodeOverlayLayer__nodeTypeExcludeList: ClassVar[dict] = ...
    kEditedNodeColor: ClassVar[PyQt5.QtGui.QColor] = ...
    kErrorNodeColor: ClassVar[PyQt5.QtGui.QColor] = ...
    kViewedNodeColor: ClassVar[PyQt5.QtGui.QColor] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def autoSetInfo(self, node: NodegraphAPI.Node, useExcludeList: bool = ...): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def setNodeName(self, name, nodeType: str = ..., nodeInfo: str = ..., useExcludeList: bool = ..., hasNodeError: bool = ..., hasViewFlag: bool = ..., hasEditFlag: bool = ...): ...

def DrawNodeNameOverlay(nodeName, nodeType, pos, wsize, defaultNodeColor, nodeTypeColor, backgroundColor, textColor, lineColor, edgePad: int = ..., nodeInfo: str = ...): ...
def GetViewMaskInfo(node: NodegraphAPI.Node): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import UI4.FormMaster.Editors.PortNameAndOrderWidget as PortNameAndOrderWidget
import PyQt5.QtCore as QtCore
import UI4.FormMaster.Editors.NodeGroup
from typing import Set, Tuple

class MultiInputPortNodeEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import ConfigurationAPI_cmodule as Configuration
import NodegraphAPI as NodegraphAPI
import RerenderEventMapper.NukeSessionMonitor as NukeSessionMonitor
import RenderingAPI as RenderingAPI
import Utils as Utils
import typing
from PyUtilModule.VirtualKatana import RenderManager as RenderManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

RENDER_NODE_NAME: str
g_nukeConfigurationError: None
g_nukeConfigured: None
g_nukeConfiguredVersion: None
g_nukeRenderNode: None

class CompTypes:
    INTERACTIVE_COMP: ClassVar[str] = ...
    LIVE_COMP: ClassVar[str] = ...
    PREVIEW_COMP: ClassVar[str] = ...

def GetCatalogItemLabel(catalogItem: CatalogAPI.CatalogItem) -> str: ...
def GetCurrentKatanaReaderNodesMapping() -> dict[str, str]: ...
def GetCurrentKatanaWriterNodeName() -> str: ...
def GetKatanaReaderNodeNames() -> list[str]: ...
def GetKatanaWriterNodeNames() -> list[str]: ...
def GetLastNukeScriptPath() -> str: ...
def GetNukeBridgeConfigurationError() -> str | None: ...
def GetNukeBridgeConfiguredVersion() -> str | None: ...
def GetNukeBridgeRenderNode() -> NodegraphAPI.Node: ...
def GetRootNukeMappingParam(): ...
def GetRootNukeOutputParam(): ...
def GetRootNukeParam(): ...
def GetRootNukeScriptParam(): ...
def GetRootNukeSessionParam(): ...
def GetSupportedNukeVersions() -> tuple[str, ...]: ...
def InitializeNukeBridge() -> bool: ...
def IsNukeBridgeConfigured() -> bool: ...
def IsNukeBridgeSession(catalogItem: CatalogAPI.CatalogItem) -> bool: ...
def LoadNukeScript(nukeScriptPath: str, inProgressHandler: Incomplete | None = ..., onErrorCallback: typing.Optional[typing.Callable] = ...) -> bool: ...
def ParseCatalogItemLabel(label: str) -> str: ...
def SetCurrentKatanaReaderNodesMapping(mapping: dict[str, str]): ...
def SetCurrentKatanaWriterNodeName(nodeName: str): ...
def StartComp(compType: str, renderFarmName: Incomplete | None = ...): ...
def _BuildNukeBridgeNodeNetwork() -> NodegraphAPI.Node: ...
def _ConfigureNukeBridge(): ...
def _ResetKatanaNodeNames(katanaNodes: dict): ...
def _RunCommand(commandArguments: list[str], inProgressHandler: Incomplete | None = ...): ...
def _WriteOrGetTempGetKatanaNodesScriptPath() -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.SceneGraphView.Bridge
import UI4.Widgets.SceneGraphView.SceneGraphHandle
import UI4.Widgets.SceneGraphView.SceneGraphViewColumn
from typing import Any, Set, Tuple

AttributeMode: int
ParameterMode: int

class Target:
    def __init__(self, sceneGraphColumn: SceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.SceneGraphColumnSet], bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], mode: int = ...) -> None: ...
    def getSceneGraphColumn(self) -> SceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.SceneGraphColumn]: ...
    def resolve(self, handle: SceneGraphHandle[UI4.Widgets.SceneGraphView.SceneGraphHandle.SceneGraphHandle], topLevelHandle: SceneGraphHandle[UI4.Widgets.SceneGraphView.SceneGraphHandle.SceneGraphHandle]) -> Any: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import UI4.Tabs.NodeGraphTab.Layers.LinkConnectionLayer as LinkConnectionLayer
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class MergeNodeInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    pressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def _MergeNodeInteractionLayer__deletePortCallback(self, mId: Incomplete | None = ...): ...
    def _MergeNodeInteractionLayer__multiOutPopupChosen(self, text, meta): ...
    def _MergeNodeInteractionLayer__multiPopClosed(self): ...
    def _MergeNodeInteractionLayer__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _MergeNodeInteractionLayer__renamePortCallback(self, menuid: int = ...): ...
    def _MergeNodeInteractionLayer__unhilite(self): ...
    def addMultiOutPopupCallback(self, cb): ...
    def processEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CacheManager as CacheManager
import NodegraphAPI as NodegraphAPI
import Utils as Utils
import typing
from Nodes3DAPI.Node3D_geolib3 import _GetPushDependencies as _GetPushDependencies
from typing import Any, Set, Tuple

NodegraphEventTypes: dict
kNodePortChangeEventsKey: int
kParamChangedEventsKey: int
kPortConnectionEventsKey: int

class InputGraphBasedCacheManager:
    def __init__(self) -> None: ...
    def _InputGraphBasedCacheManager__on_node_delete(self, eventType, eventID, node: NodegraphAPI.Node, oldName): ...
    def _InputGraphBasedCacheManager__on_nodegraphChangedEvent(self, eventName, eventId, **kwargs): ...
    def _InputGraphBasedCacheManager__resolveInvalidations(self): ...
    def cacheValue(self, node: NodegraphAPI.Node, graphState: NodegraphAPI.GraphState, portIndex: int, value: object, getInputNodesFnc: typing.Callable): ...
    def clear(self): ...
    def discard(self, node: NodegraphAPI.Node): ...
    def getCachedValue(self, node: NodegraphAPI.Node, graphState: NodegraphAPI.GraphState, portIndex: int) -> Any: ...

class _NodeRecord:
    def __init__(self) -> None: ...
    def getValue(self, graphState: NodegraphAPI.GraphState, portIndex): ...
    def invalidate(self): ...
    def invalidateCache(self): ...
    def setValue(self, graphState: NodegraphAPI.GraphState, portIndex, value): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from UI4.Tabs.AttributesTab.AttributesTab import AttributesTab as AttributesTab
from typing import Set, Tuple

PluginRegistry: list



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Browser as Browser, FileBrowser as FileBrowser, FileInfo as FileInfo
from AssetBrowser.BrowserColumn import BrowserColumn as BrowserColumn
from AssetBrowser.NonexclusiveCheckboxPopup import NonexclusiveCheckboxPopup as NonexclusiveCheckboxPopup
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Callbacks as Callbacks
import CatalogAPI as CatalogAPI
import CatalogAPI.CatalogUtils as CatalogUtils
import PyUtilModule.KatanaFile as KatanaFile
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyOpenColorIO as OCIO
import PyResolutionTableFn as ResolutionTable
import Utils as Utils
import re
import typing
from PyUtilModule.ProjectSnapshot import ProjectSnapshot as ProjectSnapshot, SnapshotType as SnapshotType
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CatalogItem:
    kFrameRangePattern: ClassVar[re.Pattern] = ...
    def __init__(self, catalogItemID) -> None: ...
    def _CatalogItem__getBufferInfoIndex(self, layerview): ...
    @classmethod
    def _CatalogItem__parseFrameRange(cls, frameRange: str) -> tuple[int, ...]: ...
    def _CatalogItem__setSimpleValue(self, name, value): ...
    def _CatalogItem__setSimpleValues(self, namesValues): ...
    def _CatalogItem__setStringArrayValue(self, paramName, values): ...
    def _saveImagesToDisk(self): ...
    def _saveThumbnailToDisk(self): ...
    def appendToRenderLog(self, message): ...
    def getBuffer(self, layerview, loadIfNeeded: bool = ..., strict: bool = ...): ...
    def getBufferInfo(self) -> typing.Optional[list[d]]: ...
    def getCatalogItemID(self) -> str: ...
    def getCatalogItemIDAsLabel(self) -> str: ...
    def getChannels(self, layerview, loadIfNeeded: bool = ...): ...
    def getDataWindow(self, layerview, loadIfNeeded: bool = ...): ...
    def getDiskImageLocation(self, layerview): ...
    def getDiskImageSequence(self, layerview): ...
    def getDiskThumbnailLocation(self): ...
    def getDisplayWindow(self, layerview, loadIfNeeded: bool = ...): ...
    def getDisplayWindowAsText(self, layerview, loadIfNeeded: bool = ...): ...
    def getEndFrame(self) -> int: ...
    def getFrameRange(self): ...
    def getIndex(self): ...
    def getLayerRenderCameraPath(self, layer) -> str: ...
    def getLayerViewForSequenceID(self, sequenceID): ...
    def getLayerViews(self): ...
    def getLayerViewsAsText(self, abbreviate: bool = ...): ...
    def getLayerViewsWithBuffers(self): ...
    def getMainSequenceID(self) -> int | None: ...
    def getMemoryUsage(self): ...
    def getNodeName(self): ...
    def getParam(self): ...
    def getPrimaryLayerView(self): ...
    def getProjectSnapshot(self) -> ProjectSnapshot: ...
    def getRenderCamera(self) -> tuple[int, str]: ...
    def getRenderElapsedTime(self): ...
    def getRenderElapsedTimeAsText(self): ...
    def getRenderEndTime(self): ...
    def getRenderError(self): ...
    def getRenderLog(self): ...
    def getRenderMethodType(self) -> str | None: ...
    def getRenderProgress(self): ...
    def getRenderStartTime(self): ...
    def getRenderStartTimeAsText(self): ...
    def getRenderState(self): ...
    def getRenderStats(self): ...
    def getResolutionName(self, layerview, loadIfNeeded: bool = ..., useMisc: bool = ...): ...
    def getSampleRate(self, layerview, loadIfNeeded: bool = ...): ...
    def getSequenceIDs(self) -> list[int]: ...
    def getShortDescription(self) -> str: ...
    def getSlot(self): ...
    def getStartFrame(self) -> int: ...
    def getThumbnailPixmap(self): ...
    def getTileOrdering(self): ...
    def getUserComment(self): ...
    def hasOverscan(self, layerview, loadIfNeeded: bool = ...): ...
    def is2D(self): ...
    def isDiskImageLocationLocal(self, layerview): ...
    def isFramePinned(self) -> bool: ...
    def isGSVPinned(self, gsvName: str) -> bool: ...
    def isInProgress(self) -> bool: ...
    def isLayerAdaptative(self) -> bool: ...
    def isLiveRender(self) -> bool: ...
    def isLocked(self): ...
    def isPersistant(self): ...
    def isStaticScene(self) -> bool: ...
    def isValid(self): ...
    def queryRegionStats(self, layerview, region, ignoreNanInfValues: bool = ..., minInf: Incomplete | None = ..., maxInf: Incomplete | None = ...): ...
    def releaseBuffer(self, layerview: None): ...
    def releaseBuffers(self): ...
    def renameLayerView(self, oldLayerView: None, newLayerView: None): ...
    def resetRenderLog(self): ...
    def set2D(self, is2D): ...
    def setBufferDict(self, bufferDict): ...
    def setBufferInfo(self, bufferInfo): ...
    def setDiskImageLocation(self, filename, layerview): ...
    def setDiskThumbnailLocation(self, filename): ...
    def setFramePinned(self, isPinned: bool): ...
    def setFrameRange(self, frameRange): ...
    def setGSVPinned(self, gsvName: str, isPinned: bool): ...
    def setLayerAdaptative(self, value: bool): ...
    def setLayerRenderCameraPath(self, layer: str, renderCameraPath: str): ...
    def setLock(self, isLocked): ...
    def setNodeName(self, name): ...
    def setPersistant(self, isPersistant): ...
    def setProjectSnapshot(self, projectSnapshot: ProjectSnapshot): ...
    def setRenderCamera(self, renderCameraType: int, renderCameraPath: str): ...
    def setRenderEndTime(self, t): ...
    def setRenderError(self, errorCode, nodeName, message): ...
    def setRenderMethodType(self, renderMethodType: str | None): ...
    def setRenderProgress(self, tasksCompleted, totalTasks): ...
    def setRenderStartTime(self, t): ...
    def setRenderState(self, state): ...
    def setRenderStats(self, stats): ...
    def setSampleRate(self, sampleRate): ...
    def setSlot(self, value): ...
    def setStaticScene(self, value: bool): ...
    def setThumbnailPixmap(self, value): ...
    def setTileOrdering(self, value): ...
    def setUserComment(self, value: str, final: bool = ...): ...
    def syncProjectSettings(self, makeActive: bool = ...): ...
    def toggleLock(self): ...
    def __eq__(self, other) -> bool: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other) -> bool: ...

def CreateCatalogItemFromID(catalogItemID): ...
def _ClearItemAttrs(catalogItemIDs: Incomplete | None = ...): ...
def _GetItemAttr(catalogItemID, name, default: Incomplete | None = ...): ...
def _SetItemAttr(catalogItemID, name, value): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI_cmodule as Nodes2DAPI_cmodule
import Utils as Utils
from typing import Set, Tuple

THUMBNAIL_UPDATE_CONTINUOUS: int
THUMBNAIL_UPDATE_NEVER: int
THUMBNAIL_UPDATE_ONCE: int

def GetThumbnailMode(): ...
def RegenerateAllThumbnails(): ...
def RenderThumbnail(node: NodegraphAPI.Node, priorCacheID: str = ..., size: tuple = ...): ...
def SetThumbnailMode(mode): ...
def SetThumbnailSampleRate(sampleRate): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.NodeExtensions as NodeExtensions
import NodegraphAPI_cmodule
import NodegraphAPI.NodegraphGlobals as NodegraphGlobals
import Utils as Utils
from NodegraphAPI_cmodule import PythonGroupNode as PythonGroupNode, node_createNode as node_createNode, node_registerPythonGroupType as node_registerPythonGroupType
from _typeshed import Incomplete
from typing import Set, Tuple

class GroupStackNode(NodegraphAPI_cmodule.PythonGroupNode):
    def __init__(self) -> None: ...
    def addParameterHints(self, attrName, inputDict): ...
    def allowChildReparentingViaDrag(self, childNode): ...
    def buildChildNode(self, adoptNode: Incomplete | None = ...): ...
    def canAdoptNodes(self, nodes): ...
    def deleteChildNode(self, childNode): ...
    def getChildNodeType(self): ...
    def getChildNodes(self): ...
    def getDefaultNodeShapeAttrs(self): ...
    def getDisplayNameExpression(self): ...
    def getDisplayNameForChildNode(self, childNode): ...
    def getInfoString(self): ...
    def positionChildNodes(self): ...
    def preprocessChildReparentingViaDrag(self, childNode): ...
    def reorderChildNode(self, fromIndex, toIndex): ...
    def setChildNodeType(self, nodeType): ...
    def setDisplayNameExpression(self, exprText): ...
    def setExplicitChildOrder(self, childNodeList): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
import typing
from PyUtilModule.VirtualKatana import Widgets as Widgets
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

_DisallowedNodeTypes: list
_DisallowedParentTypes: list

class NodeFindPopupButton(FilterablePopupButton):
    _NodeFindPopupButton__normalPixmap: ClassVar[None] = ...
    _NodeFindPopupButton__rolloverPixmap: ClassVar[None] = ...
    def __init__(self, goToNodeCallback: typing.Optional[typing.Callable] = ..., parent: Incomplete | None = ...) -> None: ...
    def _NodeFindPopupButton__findFilterTypeCallback(self, name, meta, matchstring): ...
    def _NodeFindPopupButton__loadPixmaps(self): ...
    def _NodeFindPopupButton__on_itemChosen(self, nodeName, meta: Incomplete | None = ...): ...
    def _NodeFindPopupButton__on_nodegraphChanged(self, args): ...
    def _NodeFindPopupButton__on_popupAboutToShow(self): ...
    def _NodeFindPopupButton__on_preferenceChanged(self, eventType, eventID, prefKey, prefValue): ...
    def _NodeFindPopupButton__on_selectAllMatchingButtonClicked(self): ...
    def _NodeFindPopupButton__on_showOnlyNodesInThisGroupChanged(self, value, name, meta): ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def setCurrentNodeView(self, node: NodegraphAPI.Node): ...
    def showPopup(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtCore as QtCore
import Utils as Utils
from typing import Set, Tuple

class TimerCallbackObject:
    def __init__(self, callbackFn, interval, registerStack, suppressCallbackDurationWarning: bool = ...) -> None: ...
    def _TimerCallbackObject__timer_CB(self): ...
    def getCallback(self): ...
    def getInternalTime(self): ...
    def getIntervalText(self): ...
    def getName(self): ...
    def getNumCalls(self): ...
    def getNumExceededThresholds(self): ...

def InitializePluginManager(): ...
def PrintStatistics(): ...
def RegisterTimerCallback(callbackFn, interval, suppressCallbackDurationWarning: bool = ...): ...
def UnregisterTimerCallback(callbackFn): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import logging
from UI4.Util.LogRecord import LogRecord as LogRecord
from typing import Set, Tuple

gLogRecordItemModel: None

class LogRecordHandler(logging.Handler):
    def __init__(self, logRecordItemModel: LogRecordItemModel) -> None: ...
    def emit(self, record: logging.LogRecord): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.SceneGraphView.Filtering
import UI4.Widgets.SceneGraphView.SceneGraphHandle
import UI4.Widgets.SceneGraphView.SceneGraphViewColumn
import Utils as Utils
import typing
from UI4.Widgets.SceneGraphView.Filtering.Criteria import Criteria as Criteria
from UI4.Widgets.SceneGraphView.Filtering.Evaluator import GetEvaluatorInstance as GetEvaluatorInstance, GetRegisteredEvaluators as GetRegisteredEvaluators
from UI4.Widgets.SceneGraphView.Filtering.Rule import Rule as Rule
from UI4.Widgets.SceneGraphView.Filtering.Target import Target as Target
from typing import ClassVar, Set, Tuple

class MatchAllRuleMatchStrategy(RuleMatchStrategy):
    def execute(self, handle, topLevelHandle, ruleSet): ...

class MatchAnyRuleMatchStrategy(RuleMatchStrategy):
    def execute(self, handle, topLevelHandle, ruleSet): ...

class RuleManager:
    MatchAllPolicy: ClassVar[int] = ...
    MatchAnyPolicy: ClassVar[int] = ...
    def __init__(self, bridge, evaluateRuleCallback: typing.Callable) -> None: ...
    def _RuleManager__callRuleEvaluationCallback(self): ...
    def _RuleManager__populateAvailableMatchingPolicies(self): ...
    def addRule(self, ruleName: str): ...
    def clearRuleCriteria(self, ruleName: str, triggerEvaluation: bool = ...): ...
    def getCurrentRules(self): ...
    def getRuleByName(self, ruleName: str) -> Rule | None: ...
    def getRuleMatchInversion(self) -> bool: ...
    def match(self, handle: SceneGraphHandle[UI4.Widgets.SceneGraphView.SceneGraphHandle.SceneGraphHandle], topLevelHandle: SceneGraphHandle[UI4.Widgets.SceneGraphView.SceneGraphHandle.SceneGraphHandle]) -> bool: ...
    def removeRule(self, ruleName: str): ...
    def renameRule(self, oldName: str, newName: str) -> str: ...
    def setRuleComment(self, ruleName: str, comment: str | None): ...
    def setRuleCriteria(self, ruleName: str, criteriaName: str, criteria: Criteria[UI4.Widgets.SceneGraphView.Filtering.Criteria]): ...
    def setRuleEnabled(self, ruleName: str, isEnabled: bool, triggerEvaluation: bool = ...): ...
    def setRuleEvaluator(self, ruleName: str, evaluator: Evaluator[UI4.Widgets.SceneGraphView.Filtering.Evaluator], useDefaultCriteria: bool = ...): ...
    def setRuleInverted(self, ruleName: str, isInverted: bool, triggerEvaluation: bool = ...): ...
    def setRuleMatchInversion(self, invertMatch: bool): ...
    def setRuleMatchPolicy(self, policy: int): ...
    def setRuleShowChildren(self, ruleName, showChildren, triggerEvaluation: bool = ...): ...
    def setRuleTarget(self, ruleName: str, column: SceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.SceneGraphColumn]): ...

class RuleManagerException(Exception):
    def __init__(self, errorMessage) -> None: ...

class RuleMatchStrategy:
    def execute(self, handle: SceneGraphHandle[UI4.Widgets.SceneGraphView.SceneGraphHandle.SceneGraphHandle], topLevelHandle: SceneGraphHandle[UI4.Widgets.SceneGraphView.SceneGraphHandle.SceneGraphHandle], ruleSet) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import DragOverlay as DragOverlay, DragTabs as DragTabs, Edge as Edge, Layouts as Layouts
from QT4Panels.DragTabs import TabDragHandle as TabDragHandle
from QT4Panels.PanelFrame import PanelFrame as PanelFrame
from QT4Panels.PanelLayout import PanelLayout as PanelLayout
from typing import Set, Tuple

Layout2Sides: tuple
Layout2Stack: tuple
LayoutQuad: tuple
LayoutSingle: tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def CopyExrWithTranscode(sourceFile, destFile, mipmap: bool = ..., roundUp: bool = ..., tileSize: int = ..., compression: str = ..., disableFiltering: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.Constants.ApplyWhenOptions as ApplyWhenOptions
import AssetAPI as AssetAPI
import ConditionalStateGrammar as ConditionalStateGrammar
import PyFnAttribute as FnAttribute
import PyFnGeolibServices as FnGeolibServices
import NodegraphAPI as NodegraphAPI
from ConditionalStateGrammar.Parser import ParseCSG as ParseCSG
from Nodes3DAPI.Node3D import Node3D as Node3D
from Nodes3DAPI.TimingUtils import GetModifiedFrameTime as GetModifiedFrameTime, GetTimingParameterHints as GetTimingParameterHints, GetTimingParameterXML as GetTimingParameterXML
from typing import Set, Tuple

_ParamHints: dict
_Parameter_XML: str

class AttributeFile_In(Node3D):
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
import UI4.Widgets.WidgetHilightBox as WidgetHilightBox
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CatalogItemThumbnailMixin:
    def __init__(self, catalogItem: Incomplete | None = ...) -> None: ...
    def _onCatalogItemChanged(self): ...
    def _updateThumbnailPixmap(self, width: int, height: int) -> bool: ...
    def getCatalogItem(self) -> CatalogItem: ...
    def setCatalogItem(self, catalogItem: CatalogItem): ...

class CatalogThumbnailWidget(CatalogItemThumbnailMixin, PyQt5.QtWidgets.QWidget):
    catalogItemDropped: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def _CatalogThumbnailWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogThumbnailWidget__catalog_itemThumbnailUpdate_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogThumbnailWidget__startDrag(self): ...
    def _onCatalogItemChanged(self): ...
    def customEvent(self, event): ...
    def dragEnterEvent(self, event): ...
    def dragLeaveEvent(self, ev): ...
    def dropEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def paintEvent(self, event): ...
    def sizeHint(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.GroupStack
from NodegraphAPI.GroupStack import GroupStackNode as GroupStackNode
from NodegraphAPI_cmodule import node_registerPythonGroupType as node_registerPythonGroupType
from typing import Set, Tuple

class InteractiveRenderFiltersNode(NodegraphAPI.GroupStack.GroupStackNode):
    def __init__(self) -> None: ...
    def addParameterHints(self, attrName, inputDict): ...
    def getDisplayNameForChildNode(self, child): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import typing
from Utils.Exceptions import GetExceptionMessage as GetExceptionMessage
from _typeshed import Incomplete
from typing import Set, Tuple

_CollapsedHandlers: dict
_CollapsedHandlersByObjectID: dict
_EventFilters: list
_EventHandlers: dict
_EventHandlersByObjectID: dict
_RegistrationCallbacks: dict
_insideHandler: bool
_removedCollapsed: list
_removedHandlers: list

def CallRegistrationCallbacks(instance: object): ...
def FilterEvent(eventType, eventID, **kwargs): ...
def GetAllRegisteredEventTypes(): ...
def GetNumRegisteredHandlersForEventType(eventType): ...
def IsCollapsedHandlerRegisteredAfterEventLoop(handler, eventType, eventID): ...
def IsCollapsedRegistered(handler, eventType: Incomplete | None = ..., eventID: Incomplete | None = ...): ...
def IsEventFilterRegistered(eventFilter: typing.Callable) -> bool: ...
def IsHandlerRegistered(handler, eventType: Incomplete | None = ..., eventID: Incomplete | None = ...): ...
def IsHandlerRegisteredAfterEventLoop(handler, eventType, eventID): ...
def IsHandlerRegisteredForEventType(eventType, checkEventID: bool = ...): ...
def ProcessDeadHandlers(): ...
def RegisterCollapsedHandler(handler, eventType: Incomplete | None = ..., eventID: Incomplete | None = ..., enabled: bool = ...): ...
def RegisterEventFilter(eventFilter): ...
def RegisterEventHandler(handler, eventType: Incomplete | None = ..., eventID: Incomplete | None = ..., enabled: bool = ...): ...
def SetRegistrationCallbackForType(cls: type, callback: typing.Callable): ...
def UnregisterCollapsedHandler(handler, eventType: Incomplete | None = ..., eventID: Incomplete | None = ...): ...
def UnregisterEventFilter(eventFilter: typing.Callable): ...
def UnregisterEventHandler(handler, eventType: Incomplete | None = ..., eventID: Incomplete | None = ...): ...
def UnregisterObjectEventHandlers(objectID: int): ...
def _registerCollapsedHandler(handler, eventType, eventID): ...
def _registerEventHandler(handler, eventType, eventID): ...
def _unregisterCollapsedHandler(handler, eventType, eventID): ...
def _unregisterCollapsedHandlerReal(handler, eventType, eventID): ...
def _unregisterEventHandler(handler, eventType, eventID): ...
def _unregisterEventHandlerReal(handler, eventType, eventID): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster as FormMaster
import GeoAPI as GeoAPI
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RegisterToCamera as RegisterToCamera
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import Nodes3DAPI.TransformUtil as TransformUtil
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from typing import Set, Tuple

class HomogeneousTransformEditor(GroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _HomogeneousTransformEditor__assignTransform(self, matrix): ...
    def _HomogeneousTransformEditor__assignTranslation(self, matrix): ...
    def _HomogeneousTransformEditor__copyLocal(self): ...
    def _HomogeneousTransformEditor__copyWorld(self): ...
    def _HomogeneousTransformEditor__fitBounds(self): ...
    def _HomogeneousTransformEditor__getLocationPath(self): ...
    def _HomogeneousTransformEditor__getLocationProducer(self): ...
    def _HomogeneousTransformEditor__hasInputProducer(self): ...
    def _HomogeneousTransformEditor__registerToCamera(self): ...
    def _HomogeneousTransformEditor__resetTransform(self): ...
    def _HomogeneousTransformEditor__snapToWorldPos(self): ...
    def _HomogeneousTransformEditor__toolsAboutToShow(self, menu): ...
    def _lockChanged(self, state): ...
    def getHilightWidgets(self): ...

class _registerPlaneDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent, applyFunction, distance, planeType) -> None: ...
    def accept_CB(self): ...
    def apply_CB(self): ...
    def getResult(self): ...
    def reject_CB(self): ...
    def sizeHint(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import UI4.Widgets.SortablePanel
from UI4.Widgets.SortablePanel import ParameterExpressionPanel as ParameterExpressionPanel, ParameterSortablePanel as ParameterSortablePanel, ParameterSortablePanelFormWidget as ParameterSortablePanelFormWidget, SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from typing import Set, Tuple

class SortableDelimitedStringFormWidget(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _SortableDelimitedStringFormWidget__setValue(self): ...
    def _SortableDelimitedStringFormWidget__toggleExpression(self): ...
    def buildAddMenu(self, menu): ...
    def newEntry(self): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def panelValueChanged(self, index): ...
    def updatePanels(self): ...

class StringPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, value, numbers, factory, hints) -> None: ...
    def _StringPanel__valueChanged(self, *args, **kwds): ...
    def getValue(self): ...
    def setValue(self, text): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from UI4.Widgets.NonexclusiveCheckboxPopup import NonexclusiveCheckboxPopup as NonexclusiveCheckboxPopup
from typing import Set, Tuple

class NonexclusiveCheckboxPopupFormWidget(BaseValueFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _buildControlWidget(self, layout): ...
    def _checkControlWidget(self): ...
    def _lockChanged(self, state): ...
    def _updateControlWidget(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Utils as Utils
import typing
from PyUtilModule.WorkingSet import WorkingSet as WorkingSet
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class WorkingSetManager:
    LiveRenderUpdatesWorkingSetName: ClassVar[str] = ...
    RenderWorkingSetName: ClassVar[str] = ...
    ViewerVisibilityWorkingSetName: ClassVar[str] = ...
    _SystemWorkingSetNames: ClassVar[tuple] = ...
    _WorkingSetManager__ClearOnSceneChange: ClassVar[set] = ...
    _WorkingSetManager__OnSceneChangeCallbackRegistered: ClassVar[bool] = ...
    _WorkingSetManager__PersistentWorkingSetNames: ClassVar[set] = ...
    _WorkingSetManager__UserOnSceneChangeCallback: ClassVar[None] = ...
    _WorkingSetManager__WorkingSets: ClassVar[dict] = ...
    @classmethod
    def _WorkingSetManager__onSceneLoadOrNewScene(cls, **kwargs): ...
    @classmethod
    def clearOnSceneChangeCallback(cls): ...
    @classmethod
    def clearWorkingSetOnSceneChange(cls, workingSetName: str): ...
    @staticmethod
    def deleteWorkingSet(name: str): ...
    @staticmethod
    def getOrCreateWorkingSet(name: str, sender: Incomplete | None = ...) -> WorkingSet: ...
    @staticmethod
    def getPersistentWorkingSetNames() -> list[str]: ...
    @staticmethod
    def getWorkingSetNames() -> list[str]: ...
    @staticmethod
    def isWorkingSetPersistent(name: str) -> bool: ...
    @classmethod
    def setOnSceneChangeCallback(cls, callback: typing.Callable): ...
    @staticmethod
    def setOpArgs(op: FnGeolibOp, opArgName: str, workingSetName: str, txn: Incomplete | None = ..., opType: Incomplete | None = ..., opArgs: Incomplete | None = ..., updateOnWorkingSetChanges: bool = ...): ...
    @staticmethod
    def setWorkingSetPersistent(name: str, persistent: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import NodegraphAPI
import Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyFnGeolib
import Utils as Utils
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

class ClientManager:
    class NullUpdateSuppressor:
        def __init__(self, *args) -> None: ...
        def __enter__(self): ...
        def __exit__(self, *args): ...
    def __init__(self) -> None: ...
    def _ClientManager__addImplicitResolvers(self, txn, opInput, viewedNode): ...
    def _ClientManager__addLocationEventsToQueue(self, locationEvents: list[tuple]): ...
    def _ClientManager__addMuteResolveOp(self, txn, opInput, viewedNode): ...
    def _ClientManager__adjustNumLocationsToProcess(self, delta, lastNumLocations): ...
    def _ClientManager__getLocationEvents(self) -> list[tuple]: ...
    def _ClientManager__getLocationEventsFromClients(self, numLocations: int) -> list[tuple]: ...
    def _ClientManager__getLocationEventsFromQueue(self, numLocations: int) -> list[tuple]: ...
    def _ClientManager__getUpdateSuppressor(self): ...
    def _ClientManager__on_event_idle(self, eventType, eventID): ...
    def _ClientManager__populatePortOpClient(self, port: NodegraphAPI.Port): ...
    def _ClientManager__removePortOpClient(self): ...
    def _ClientManager__terminalOpCallback(self, portOpClient, op, graphState: NodegraphAPI.GraphState, txn): ...
    def _ClientManager__updateOpInput(self, opInput, txn, port: NodegraphAPI.Port): ...
    def _getClient(self, key: str | None) -> PyFnGeolib.GeolibRuntime.Client: ...
    def _getClientForLocation(self, location: str, key: str | None) -> PyFnGeolib.GeolibRuntime.Client: ...
    def _getClients(self) -> list[PyFnGeolib.GeolibRuntime.Client]: ...
    def activateSceneGraphLocation(self, location: str, key: Incomplete | None = ...): ...
    def closeSceneGraphLocation(self, location: str, key: Incomplete | None = ...): ...
    def createClient(self, key: str | None): ...
    def deactivateSceneGraphLocation(self, location: str, key: Incomplete | None = ...): ...
    def deleteClient(self, key: str | None): ...
    def freeze(self): ...
    def interrupt(self): ...
    def isFrozen(self): ...
    def isProcessing(self): ...
    def isStopping(self): ...
    def openSceneGraphLocation(self, location: str, key: Incomplete | None = ...): ...
    def recursiveCloseSceneGraphLocation(self, location: str, key: Incomplete | None = ...): ...
    def recursiveOpenSceneGraphLocation(self, location, key: Incomplete | None = ..., stopTypes: Incomplete | None = ...): ...
    def setAddOrUpdateLocationCallback(self, addOrUpdateLocationCallback: typing.Callable): ...
    def setBeginEventLoopCallback(self, beginEventLoopCallback: typing.Callable): ...
    def setDeleteLocationCallback(self, deleteLocationCallback: typing.Callable): ...
    def setEndEventLoopCallback(self, endEventLoopCallback: typing.Callable): ...
    def setLocationDataProcessedCallback(self, locationDataProcessedCallback: typing.Callable): ...
    def setMaxEventsToProcess(self, maxEvents): ...
    def setMinEventsToProcess(self, minEvents): ...
    def setOpenStateEventCallback(self, openStateEventCallback: typing.Callable): ...
    def setTargetTimePerIdle(self, targetTime): ...
    def setTerminalOps(self, terminalOpArgs): ...
    def setUpdateSuppressorCallback(self, updateSuppressorCallback: typing.Callable): ...
    def setViewNode(self, viewNode: Nodes3DAPI.Node3D | Nodes2DAPI.Node2D, applyImplicitResolvers: bool = ..., extraImplicitResolverOpArgs: Incomplete | None = ...): ...
    def setViewOp(self, viewOp: FnGeolibOp | None, applyImplicitResolvers: bool = ..., extraImplicitResolverOpArgs: Incomplete | None = ...): ...
    def thaw(self): ...
    def updateTerminalOps(self, terminalOpArgs, txn: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyQt5.QtWidgets
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import Utils as Utils
from UI4.Util.IconManager import GetPixmap as GetPixmap
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from types import ModuleType
from typing import ClassVar, Set, Tuple

class UpdateModePopdownButton2D(_UpdateModePopdownButton):
    POPDOWN_MODE_ICONS: ClassVar[dict] = ...
    POPDOWN_OPTIONS: ClassVar[list] = ...
    POPDOWN_TOOLTIP: ClassVar[str] = ...
    UPDATE_MODE_ARG_KEY: ClassVar[str] = ...
    def _getGlobalUpdateMode(self): ...
    def _registerEventHandlers(self): ...
    def _setGlobalUpdateMode(self, updateMode): ...

class UpdateModePopdownButton3D(_UpdateModePopdownButton):
    POPDOWN_MODE_ICONS: ClassVar[dict] = ...
    POPDOWN_OPTIONS: ClassVar[list] = ...
    POPDOWN_TOOLTIP: ClassVar[str] = ...
    UPDATE_MODE_ARG_KEY: ClassVar[str] = ...
    UpdateModes: ClassVar[ModuleType] = ...
    def _getGlobalUpdateMode(self): ...
    def _registerEventHandlers(self): ...
    def _setGlobalUpdateMode(self, updateMode): ...

class UpdateModeWidget2D(_UpdateModeWidget):
    BUTTON_TOOLTIP: ClassVar[str] = ...
    def _UpdateModeWidget2D__on_parameter_setValue(self, args): ...
    def _createPopdownButton(self): ...
    @staticmethod
    def _isUpdateModeManual(updateMode): ...
    def _registerEventHandlers(self): ...
    def _triggerManualUpdate(self): ...

class UpdateModeWidget3D(_UpdateModeWidget):
    BUTTON_TOOLTIP: ClassVar[str] = ...
    def _createPopdownButton(self): ...
    def _isGlobalDirty(self): ...
    @staticmethod
    def _isUpdateModeManual(updateMode): ...
    def _registerEventHandlers(self): ...
    def _triggerManualUpdate(self): ...

class _UpdateModePopdownButton(ToolbarButton):
    POPDOWN_MODE_ICONS: ClassVar[dict] = ...
    POPDOWN_OPTIONS: ClassVar[list] = ...
    POPDOWN_TOOLTIP: ClassVar[str] = ...
    UPDATE_MODE_ARG_KEY: ClassVar[None] = ...
    _UpdateModePopdownButton__ICON_FILES: ClassVar[dict] = ...
    _UpdateModePopdownButton__ICON_PIXMAPS: ClassVar[None] = ...
    _UpdateModePopdownButton__MINIMUM_HEIGHT: ClassVar[int] = ...
    def __init__(self, parent, registerEventHandler: bool = ...) -> None: ...
    @classmethod
    def _UpdateModePopdownButton__getUpdateModePixmap(cls, updateMode): ...
    def _UpdateModePopdownButton__on_menu_aboutToShow(self): ...
    def _UpdateModePopdownButton__on_menu_triggered(self, action): ...
    def _getGlobalUpdateMode(self): ...
    def _on_updateModeChanged(self, *args, **kwargs): ...
    def _registerEventHandlers(self): ...
    def _setGlobalUpdateMode(self, updateMode): ...
    def getUpdateMode(self): ...
    def setUpdateMode(self, updateMode): ...

class _UpdateModeWidget(PyQt5.QtWidgets.QWidget):
    BUTTON_TOOLTIP: ClassVar[str] = ...
    IS_DIRTY_ARG_KEY: ClassVar[str] = ...
    _UpdateModeWidget__ACTIVE_HILITE_ICON_FILE: ClassVar[str] = ...
    _UpdateModeWidget__ACTIVE_ICON_FILE: ClassVar[str] = ...
    _UpdateModeWidget__DIRTY_HILITE_ICON_FILE: ClassVar[str] = ...
    _UpdateModeWidget__DIRTY_ICON_FILE: ClassVar[str] = ...
    _UpdateModeWidget__INACTIVE_ICON_FILE: ClassVar[str] = ...
    def __init__(self, parent, text: Incomplete | None = ...) -> None: ...
    def _createPopdownButton(self): ...
    def _isGlobalDirty(self): ...
    def _on_dirtyStateChanged(self, *args, **kwargs): ...
    def _on_updateButtonClicked(self, *args, **kwargs): ...
    def _on_updateModeChanged(self, *args, **kwargs): ...
    def _registerEventHandlers(self): ...
    def _triggerManualUpdate(self): ...
    def isDirty(self): ...
    def setButtonType(self, buttonType: Incomplete | None = ...): ...
    def setDirty(self, dirty): ...
    def updateState(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PackageSuperToolAPI.PackageNameItemDelegate
import UI4.Tabs.SceneGraphTab.SceneGraphTabNameItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.ColorItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.LightLinkItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.MuteAndSoloItemDelegates
import UI4.Widgets.SceneGraphView.ItemDelegates.NameItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.NumberItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.ShaderItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.WorkingSetItemDelegate
from typing import ClassVar, Set, Tuple

class ColumnDataType:
    Color: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.ColorItemDelegate.ColorItemDelegate]] = ...
    Dummy: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate.DummyItemDelegate]] = ...
    LightLink: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.LightLinkItemDelegate.LightLinkItemDelegate]] = ...
    Mute: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.MuteAndSoloItemDelegates.MuteItemDelegate]] = ...
    Name: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.NameItemDelegate.NameItemDelegate]] = ...
    Number: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.NumberItemDelegate.NumberItemDelegate]] = ...
    PackageName: ClassVar[type[PackageSuperToolAPI.PackageNameItemDelegate.PackageNameItemDelegate]] = ...
    SceneGraphTabColorColumn: ClassVar[type[UI4.Tabs.SceneGraphTab.SceneGraphTabNameItemDelegate.SceneGraphTabColorColumnDelegate]] = ...
    SceneGraphTabCustomColumn: ClassVar[type[UI4.Tabs.SceneGraphTab.SceneGraphTabNameItemDelegate.SceneGraphTabCustomColumnDelegate]] = ...
    SceneGraphTabLocationName: ClassVar[type[UI4.Tabs.SceneGraphTab.SceneGraphTabNameItemDelegate.SceneGraphTabNameItemDelegate]] = ...
    Shader: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.ShaderItemDelegate.ShaderItemDelegate]] = ...
    Solo: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.MuteAndSoloItemDelegates.SoloItemDelegate]] = ...
    String: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate.ParameterItemDelegate]] = ...
    WorkingSet: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.WorkingSetItemDelegate.WorkingSetItemDelegate]] = ...

def RegisterDataType(dataTypeName: str, itemDelegateClass): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

VIEW_MASK_ALL: str

def GetActiveViews(viewMask: str) -> list[str]: ...
def GetDefaultView() -> str: ...
def GetLeftView() -> str: ...
def GetRightView() -> str: ...
def GetViewAbbreviation(view: str) -> str: ...
def GetViewProductToken(view: str) -> str: ...
def GetViewUIColor(view: str) -> tuple: ...
def GetViews() -> list[str]: ...
def IsMaskedViewActive(view: str, viewMask: str) -> bool: ...
def IsViewValid(view: str) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import PyQt5.QtWidgets
import PyXmlIO as PyXmlIO
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ShadingNodeBase as ShadingNodeBase
import UI4 as UI4
import UI4.FormMaster.GenericAssignParameterPolicy_geolib3
import UI4.FormMaster.ParameterPolicy
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from UI4.FormMaster.GenericAssignParameterPolicy import DataStoreAction as DataStoreAction, GenericAssignGroupParameterPolicy as GenericAssignGroupParameterPolicy, GenericAssignParameterPolicy as GenericAssignParameterPolicy
from UI4.FormMaster.GenericAssignParameterPolicy_geolib3 import Geolib3GenericAssignPolicyDelegate as Geolib3GenericAssignPolicyDelegate
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

g_labelClose: str
g_labelOpen: None
nodeType: str

class NetworkMaterialPolicyDelegate(UI4.FormMaster.ParameterPolicy.ParameterPolicyDelegate):
    def createPolicy(self, parentPolicy, param): ...

class NetworkMaterialPublicInterfacePolicy(BaseParameterPolicy):
    def __init__(self, param, parent, attrSource: Incomplete | None = ...) -> None: ...
    def _NetworkMaterialPublicInterfacePolicy__sourceUpdate(self): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def getAttrSource(self): ...

class ParameterExposureDialog(PyQt5.QtWidgets.QDialog):
    _ParameterExposureDialog__pageNames: ClassVar[set] = ...
    def __init__(self, policy) -> None: ...
    def _ParameterExposureDialog__on_lineEdit_textChanged(self, text): ...
    @classmethod
    def addPageName(cls, pageName): ...
    def getRootPolicy(self): ...
    def showEvent(self, event): ...
    @classmethod
    def showForPolicy(cls, policy): ...

class ShadingNodePolicy(GenericAssignParameterPolicy):
    kDestinationHints: ClassVar[set] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def _ShadingNodePolicy__applyHintDifferences(self, hints, newHints, destHints): ...
    def _ShadingNodePolicy__createOrUpdateOrDeleteHintsParameter(self, oldHints, newHints): ...
    def _ShadingNodePolicy__editHelpText(self): ...
    def _ShadingNodePolicy__editWidgetOptions(self): ...
    def _ShadingNodePolicy__getDefaultInfoText(self, hints): ...
    def _ShadingNodePolicy__hintsValueChanged(self, event): ...
    def _ShadingNodePolicy__setCoPolicyDestinations(self, coPolicyPathDict, alteredCoPolicyPathDict, dstName, dstPage, dstLabel): ...
    def _ShadingNodePolicy__widgetTypeTriggered(self, action): ...
    def _appendToWrenchMenu(self, menu: PyQt5.QtWidgets.QMenu): ...
    def _customizeWrenchButton(self, wrenchButton: PyQt5.QtWidgets.QPushButton): ...
    def _getPublicHints(self) -> dict | None: ...
    def _getPublicHintsParam(self, create: bool = ...): ...
    def _handleTopologyChanged(self, args): ...
    def _isParameterExposed(self) -> bool: ...
    def _setDestinationNameAndPage(self, dstName, dstPage, adjustCoPolicies: bool = ..., dstLabel: Incomplete | None = ...): ...
    def getWidgetHints(self): ...
    def shouldDisplayWrench(self): ...

class ShadingNodePolicyDelegate(UI4.FormMaster.GenericAssignParameterPolicy_geolib3.Geolib3GenericAssignPolicyDelegate):
    def __init__(self, attrRoot: str = ..., paramRoot: Incomplete | None = ...) -> None: ...
    def getParamAttrPath(self, param): ...

def GetAppearanceInfoText(dstName: str, dstPage: str, dstLabel: str, defaultName: str) -> str: ...
def GetHighlightedText(text: str) -> str: ...
def GetLabelClose(): ...
def GetLabelOpen(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import PyXmlIO as PyXmlIO
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.NodeMaster.NodeInteractionDelegateManager
import Utils as Utils
from typing import Set, Tuple

class IsolateDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    def _IsolateDelegate__appendIsolateScenegraphLocations(self, targetNode, locations, replace: bool = ...): ...
    def _IsolateDelegate__dialogPrompt(self, firstActionText): ...
    def _IsolateDelegate__replaceIsolateScenegraphLocations(self, targetNode, locations): ...
    def _IsolateDelegate__setIsolateRoot(self, targetNode, location): ...
    def _IsolateDelegate__validScenegraphDrop(self, targetNode, event): ...
    def acceptsDrop(self, targetNode, event): ...
    def processDrop(self, targetNode, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4GLLayerStack.Util as Util
from QT4GLLayerStack.LayerStack import Layer as Layer
from typing import Set, Tuple

class ZoomInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, name, allowLeftButton: bool = ..., allowMidButton: bool = ..., allowMouseWheel: bool = ..., *args, **kwargs) -> None: ...
    def freeze(self): ...
    def processEvent(self, e): ...
    def setAllowKeylessTabletInteraction(self, allowKeylessTabletInteraction): ...
    def setHorizontalLock(self, isLocked): ...
    def setVerticalLock(self, isLocked): ...
    def thaw(self): ...

class ZoomTransientLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, event, horizontalLock, verticalLock, prevFocusLayer, *args, **kwargs) -> None: ...
    def _ZoomTransientLayer__doVirtualDrag(self, globalPoint): ...
    def _ZoomTransientLayer__dragSensitivityFunction(self, delta): ...
    def freeze(self): ...
    def processEvent(self, e): ...
    def setAllowKeylessTabletInteraction(self, allowKeylessTabletInteraction): ...
    def setLayerStack(self, s): ...
    def thaw(self): ...
    def __del__(self) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class CheckableTreeDialog(PyQt5.QtWidgets.QDialog):
    class CheckableItem(PyQt5.QtWidgets.QTreeWidgetItem):
        def __init__(self, parent, name, enabled) -> None: ...
        def itemData(self): ...

    class CheckableTreeWidget(PyQt5.QtWidgets.QTreeWidget):
        def __init__(self, *args) -> None: ...
        def _CheckableTreeWidget__currentItemChanged(self, current, previous): ...
    def __init__(self, parent, data) -> None: ...
    def _CheckableTreeDialog__doFilterChanged(self, filterText, filterType): ...
    def getSelection(self): ...
    def sortByColumn(self, column): ...

class TreeIter(PyQt5.QtWidgets.QTreeWidgetItemIterator):
    def __init__(self, *args) -> None: ...
    def __iter__(self): ...
    def __next__(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import ArgsFile as ArgsFile, AttributeFunctionUtil as AttributeFunctionUtil, ExpressionMath as ExpressionMath, HintUtils as HintUtils, LookFile as LookFile, MaterialResolveUtil as MaterialResolveUtil, OpArgsBuilders as OpArgsBuilders, XFormUtil as XFormUtil
from typing import Set, Tuple

def bootstrapPluginSystem() -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import UI4.FormMaster.Pages as Pages
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.States as States
import Utils as Utils
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from UI4.FormMaster.GroupParameterPolicy import GroupParameterPolicy as GroupParameterPolicy
from UI4.Widgets.AttributeHistoryWidgets import AddAttributeHistoryActionsToMenu as AddAttributeHistoryActionsToMenu
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class DataStoreAction(PyQt5.QtWidgets.QAction):
    triggerWithData: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, text, parent, data) -> None: ...
    def _DataStoreAction__trigger(self): ...

class GenericArrayIndexValuePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, attr, index, parent) -> None: ...
    def _GenericArrayIndexValuePolicy__switchParentStateToLocal(self, parent): ...
    def canHaveCurve(self): ...
    def canHaveExpression(self): ...
    def getName(self): ...
    def getSceneGraphLocationPath(self) -> str | None: ...
    def getType(self): ...
    def getValue(self): ...
    def isLocked(self): ...
    def setAttr(self, attr): ...
    def setCurve(self, value): ...
    def setCurveAutoKey(self, autoKey): ...
    def setCurveEnabled(self, value): ...
    def setCurveXml(self, value): ...
    def setExpression(self, value): ...
    def setExpressionEnabled(self, value): ...
    def setValue(self, value, final: bool = ...): ...

class GenericAssignGroupParameterPolicy(GroupParameterPolicy):
    def __init__(self, param, parent, attrSource, attrPath) -> None: ...
    def _GenericAssignGroupParameterPolicy__checkForPages(self): ...
    def _GenericAssignGroupParameterPolicy__filterChildren(self, children): ...
    def _GenericAssignGroupParameterPolicy__getChildNames(self): ...
    def _GenericAssignGroupParameterPolicy__getChildPageHint(self, childName): ...
    def _GenericAssignGroupParameterPolicy__sourceAdditionalUpdate(self): ...
    def _GenericAssignGroupParameterPolicy__sourceUpdate(self): ...
    def _appendToWrenchMenu(self, menu): ...
    def _childPolicyRenamed(self, policy): ...
    def _closeButtonClicked(self): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def _updateAttrPath(self, parentPath): ...
    def filterToSubset(self, paramNameWhitelist: list[str]) -> bool: ...
    def getAttrName(self) -> str | None: ...
    def getAttrSource(self): ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getName(self): ...
    def getWidgetHints(self): ...
    def isCloseButtonEnabled(self): ...
    def setName(self, title): ...
    def shouldDisplayClose(self): ...
    def shouldDisplayWrench(self): ...
    def waitForReady(self): ...
    @property
    def filteredParameterChildren(self): ...

class GenericAssignPagePolicy(GroupParameterPolicy):
    EMPTYPAGEHINTS: ClassVar[dict] = ...
    def __init__(self, param, parent, attrSource, attrPath, pageName, childNames, childPages: Incomplete | None = ..., pagePrefix: str = ...) -> None: ...
    def _GenericAssignPagePolicy__sourceUpdate(self): ...
    def _appendToWrenchMenu(self, menu): ...
    def _closeButtonClicked(self): ...
    def _updateAttrPath(self, parentPath): ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getName(self): ...
    def getWidgetHints(self): ...
    def shouldDisplayClose(self): ...
    def shouldDisplayWrench(self): ...
    def waitForReady(self): ...

class GenericAssignParameterPolicy(BaseParameterPolicy):
    def __init__(self, param, parent, attrSource: Incomplete | None = ..., attrPath: str = ...) -> None: ...
    def _GenericAssignParameterPolicy__childValueChanged(self, event): ...
    def _GenericAssignParameterPolicy__getActivePolicy(self): ...
    def _GenericAssignParameterPolicy__getArrayChildUnproxied(self, index): ...
    def _GenericAssignParameterPolicy__getMultiAssignParam(self): ...
    def _GenericAssignParameterPolicy__sourceUpdate(self): ...
    def _appendToContextMenu(self, menu: PyQt5.QtWidgets.QMenu): ...
    def _appendToWrenchMenu(self, menu): ...
    def _closeButtonClicked(self): ...
    def _freeze(self): ...
    def _getInternalArrayChildren(self): ...
    def _getValueParam(self): ...
    def _handleEnableParamValueChange(self): ...
    def _handleParamChanged(self, args): ...
    def _handleParamFinalized(self, args: list[tuple[str, object, dict]]): ...
    def _handleTimeChanged(self, final): ...
    def _handleValuePolicyChange(self, event: ValuePolicyEvent): ...
    def _thaw(self): ...
    def _updateAttrPath(self, parentPath): ...
    def bakeCurve(self, keys): ...
    def canHaveCurve(self): ...
    def canHaveExpression(self): ...
    def checkMimeData(self, mimeData): ...
    def forceLocal(self): ...
    def getArrayChild(self, index): ...
    def getArraySize(self): ...
    def getAttrName(self) -> str | None: ...
    def getAttrSource(self): ...
    def getAvailableStates(self): ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getCurve(self): ...
    def getCurveAutoKey(self): ...
    def getCurveKey(self): ...
    def getCurveXml(self): ...
    def getExpression(self): ...
    def getExpressionError(self): ...
    def getExpressionNamespace(self): ...
    def getExpressionReference(self): ...
    def getMimeData(self) -> PyQt5.QtCore.QMimeData: ...
    def getNumChildren(self): ...
    def getType(self): ...
    def getValue(self): ...
    def getValueState(self): ...
    def getWidgetHints(self): ...
    def hasFloatingCurve(self): ...
    def isCloseButtonEnabled(self): ...
    def isCurveEnabled(self): ...
    def isCurveViewed(self): ...
    def isExpressionEnabled(self): ...
    def loadCurveFromFile(self, path, curvename: str = ...): ...
    def removeArrayChild(self, index): ...
    def removeArrayChildren(self, index, count): ...
    def reorderArrayChild(self, oldIndex, newIndex): ...
    def reorderArrayChildren(self, oldIndex, newIndex, count): ...
    def setArraySize(self, size): ...
    def setCurve(self, curve): ...
    def setCurveAutoKey(self, autoKey): ...
    def setCurveEnabled(self, state): ...
    def setCurveKey(self, state): ...
    def setCurveViewed(self, state): ...
    def setCurveXml(self, xml): ...
    def setExpression(self, rawExpr): ...
    def setExpressionEnabled(self, flag): ...
    def setMimeData(self, mimeData, dropAction): ...
    def setValue(self, value, final: bool = ...): ...
    def setValueFromString(self, strValue, final: bool = ...): ...
    def setValueState(self, state): ...
    def shouldDisplayClose(self): ...
    def shouldDisplayState(self): ...
    def shouldDisplayWrench(self): ...
    def waitForReady(self): ...
    def writeCurveToFile(self, path): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from QT4FormWidgets.ExpressionEditDialog import ExpressionEditDialog as ExpressionEditDialog
from QT4FormWidgets.StateChangeAction import StateChangeAction as StateChangeAction
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import Set, Tuple

class PasteMenu(PyQt5.QtWidgets.QMenu):
    def __init__(self, source, parent, locked) -> None: ...
    def _PasteMenu__doShow(self): ...
    def _PasteMenu__pasteAll(self): ...
    def _PasteMenu__pasteLink(self): ...
    def _PasteMenu__pasteValue(self): ...
    def copySource(self): ...

def AddPolicyTypeActions(menu, policy, locked, doConstant: Incomplete | None = ..., doCurve: Incomplete | None = ..., doExpression: Incomplete | None = ..., doKey: Incomplete | None = ..., doAutoKey: Incomplete | None = ..., doShowCurve: Incomplete | None = ...): ...
def AddValueStateMenuItems(menu: PyQt5.QtWidgets.QMenu, policy: QT4FormWidgets.AbstractValuePolicy, locked: bool): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import Utils as Utils
from typing import Set, Tuple

def DoesNodeTrigger2DRender(node: NodegraphAPI.Node): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyFnAttribute as FnAttribute
import GeoAPI as GeoAPI
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
from QT4FormWidgets.StringFormWidget import StringFormWidget
from typing import Set, Tuple

class LookFilePassname(StringFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _LookFilePassname__chooseLookFilePassFromProduct(self): ...
    def _LookFilePassname__chooseLookFilePassFromSelection(self): ...
    def _LookFilePassname__menuAboutToShow(self, menu): ...
    def _buildControlWidget(self, layout): ...
    def askForPassAndSetIt(self, passes): ...
    def generateMenu(self): ...
    def getLookFilePassesFromProduct(self): ...
    def getLookFilePassesFromSelection(self): ...
    def getProductParam(self): ...
    def getProductValue(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4Color as QT4Color
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.FormMaster.BaseParameterPolicy
import UI4.Widgets.SceneGraphView.Bridge
import Utils as Utils
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate import ParameterItemDelegate as ParameterItemDelegate
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ColorItemDelegate(ParameterItemDelegate):
    ColorSwatchWidth: ClassVar[int] = ...
    DefaultColumnWidth: ClassVar[int] = ...
    MaximumColumnWidth: ClassVar[int] = ...
    Padding: ClassVar[int] = ...
    PaddingRight: ClassVar[int] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def _ColorItemDelegate__getDisplayValues(self, index): ...
    def createEditor(self, parent: PyQt5.QtWidgets.QWidget, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> PyQt5.QtWidgets.QWidget | None: ...
    def doesParameterValueMatchModelValue(self, parameterPolicy: BaseParameterPolicy[UI4.FormMaster.BaseParameterPolicy.BaseParameterPolicy], index: PyQt5.QtCore.QModelIndex) -> bool: ...
    def isFilmlookEnabled(self) -> bool: ...
    def paint(self, painter: PyQt5.QtGui.QPainter, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def setFilmlookEnabled(self, filmlookEnabled: bool): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import Utils as Utils
from typing import Set, Tuple

class CropWindowLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def initializeGL(self): ...
    def paintGL(self): ...
    def setDisplayRect(self, displayRect): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import PyQt5.QtCore as QtCore
import UI4.NodeMaster.NodeInteractionDelegateManager
import Utils as Utils
from typing import Set, Tuple

class PruneDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    def _PruneDelegate__appendScenegraphLocations(self, targetNode, locations): ...
    def _PruneDelegate__replaceScenegraphLocations(self, targetNode, locations): ...
    def _PruneDelegate__validScenegraphDrop(self, targetNode, event): ...
    def acceptsDrop(self, targetNode, event): ...
    def processDrop(self, targetNode, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Evaluator as Evaluator
from UI4.Widgets.SceneGraphView.Filtering.Criteria import Criteria as Criteria
from UI4.Widgets.SceneGraphView.Filtering.Evaluator import GetEvaluatorCriteria as GetEvaluatorCriteria, GetEvaluatorInstance as GetEvaluatorInstance, GetRegisteredEvaluators as GetRegisteredEvaluators, RegisterEvaluator as RegisterEvaluator
from UI4.Widgets.SceneGraphView.Filtering.Rule import Rule as Rule
from UI4.Widgets.SceneGraphView.Filtering.RuleConfigDialog import RuleConfigDialog as RuleConfigDialog
from UI4.Widgets.SceneGraphView.Filtering.RuleManager import RuleManager as RuleManager
from UI4.Widgets.SceneGraphView.Filtering.Target import Target as Target
from typing import Set, Tuple

AttributeMode: int



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from UI4.Widgets.CatalogChannelsWidget import CatalogChannelsWidget as CatalogChannelsWidget
from UI4.Widgets.CatalogFrameRangeWidget import CatalogFrameRangeWidget as CatalogFrameRangeWidget
from UI4.Widgets.CatalogLockWidget import CatalogLockWidget as CatalogLockWidget
from UI4.Widgets.CatalogNameWidget import CatalogNameWidget as CatalogNameWidget
from UI4.Widgets.CatalogProgressWidget import CatalogProgressWidget as CatalogProgressWidget
from UI4.Widgets.CatalogResolutionWidget import CatalogResolutionWidget as CatalogResolutionWidget
from UI4.Widgets.CatalogStopWidget import CatalogStopWidget as CatalogStopWidget
from UI4.Widgets.CatalogThumbnailWidget import CatalogThumbnailWidget as CatalogThumbnailWidget
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CatalogItemWidget(PyQt5.QtWidgets.QWidget):
    catalogItemDropped: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _CatalogItemWidget__catalogItemDropped_CB(self, item): ...
    def getLockLayout(self) -> PyQt5.QtWidgets.QHBoxLayout: ...
    def getNameLayout(self) -> PyQt5.QtWidgets.QHBoxLayout: ...
    def setCatalogItem(self, item): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class ExternalEditorDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self) -> None: ...
    def go(self, textValue, suffix: str = ...): ...
    def reject(self): ...

def EditPolicy(policy): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import Utils as Utils
from UI4.Widgets.IconLabelFrame import IconLabelFrame as IconLabelFrame
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class IndicatorLabelFrame(IconLabelFrame):
    _IndicatorLabelFrame__pixmaps: ClassVar[dict] = ...
    def __init__(self, activeIconName: Incomplete | None = ..., inactiveIconName: Incomplete | None = ..., autoHide: bool = ..., parent: Incomplete | None = ..., flags: PyQt5.QtCore.Qt.WindowType = ...) -> None: ...
    def _IndicatorLabelFrame__getPixmap(self, iconName: str) -> PyQt5.QtGui.QPixmap: ...
    def _IndicatorLabelFrame__linkClicked(self, link: str): ...
    def setAutoHide(self, autoHide: bool): ...
    def updateDisplay(self, active: bool, message: str = ..., nodeNames: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import QT4Widgets.WidgetUtils as WidgetUtils
from QT4FormWidgets.FWidget import FWidget
from UI4.Widgets.ToolbarButton import ToolbarButton
from _typeshed import Incomplete
from typing import Set, Tuple

class PolicyFindPopupButton(ToolbarButton):
    def __init__(self, tooltip: str, parent: PyQt5.QtWidgets.QWidget) -> None: ...
    def _PolicyFindPopupButton__locationFilterCallback(self, state, name, meta): ...
    def _PolicyFindPopupButton__on_popup_hide(self): ...
    def _PolicyFindPopupButton__on_popup_itemChosen(self, text, meta): ...
    def _PolicyFindPopupButton__on_popup_show(self): ...
    def _PolicyFindPopupButton__on_pressed(self): ...
    def findPolicy(self, path): ...

class PolicyFindPopupFWidget(FWidget):
    def __init__(self, parent, pixmap: Incomplete | None = ...) -> None: ...
    def _PolicyFindPopupFWidget__itemChosen(self, text, meta): ...
    def _PolicyFindPopupFWidget__locationFilterCallback(self, state, name, meta): ...
    def _PolicyFindPopupFWidget__popupHidden(self): ...
    def _PolicyFindPopupFWidget__popupShow(self): ...
    def _PolicyFindPopupFWidget__showFindPopup(self): ...
    def findPolicy(self, path): ...
    def mousePressEvent(self, event): ...
    def paint(self, painter, width, height): ...
    def sizeHint(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.NodeHints.Common2D import GetGainNumberDict as GetGainNumberDict, GetGammaNumberDict as GetGammaNumberDict, GetOffsetNumberDict as GetOffsetNumberDict, GetSaturationNumberDict as GetSaturationNumberDict
from typing import Set, Tuple

_NodeHints: dict
_NodeName: str



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Constants as Constants, Exceptions as Exceptions, InteractiveRenderDelegateManager as InteractiveRenderDelegateManager, NodegraphUtils as NodegraphUtils, RenderCore as RenderCore, RenderGlobals as RenderGlobals, RenderSettings as RenderSettings, RenderTriggers as RenderTriggers, ResolutionTableUtils as ResolutionTableUtils, ScenegraphUtils as ScenegraphUtils
from PyUtilModule.RenderManager.Constants import RenderModes as RenderModes
from PyUtilModule.RenderManager.Exceptions import RenderingException as RenderingException, UnsupportedRenderMethodNameException as UnsupportedRenderMethodNameException
from PyUtilModule.RenderManager.RenderCore import CancelRender as CancelRender, CancelRendersByType as CancelRendersByType, StartRender as StartRender, StartRenderLegacy as StartRenderLegacy
from PyUtilModule.RenderManager.RenderGlobals import ClearSequenceIDMaps as ClearSequenceIDMaps, GetAvailableSampleRates as GetAvailableSampleRates, GetBuffer2DAutoLock as GetBuffer2DAutoLock, GetDefaultSampleRate as GetDefaultSampleRate, GetDiskCachingAllowed as GetDiskCachingAllowed, GetInteractiveSampleRate as GetInteractiveSampleRate, GetLiveRenderOpTreePath as GetLiveRenderOpTreePath, GetOverscanPadding as GetOverscanPadding, GetRenderIDPass as GetRenderIDPass, GetRenderMode as GetRenderMode, GetRenderNodeTypes as GetRenderNodeTypes, GetRenderROI as GetRenderROI, GetRenderRawROI as GetRenderRawROI, GetRenderUseROI as GetRenderUseROI, GetRenderViews as GetRenderViews, GetRenderViewsAutoUpdate as GetRenderViewsAutoUpdate, GetRerenderCamera as GetRerenderCamera, GetRerenderMode as GetRerenderMode, GetRerenderNodeName as GetRerenderNodeName, GetRerenderRenderProducer as GetRerenderRenderProducer, GetRerenderRendererName as GetRerenderRendererName, GetSampleRate as GetSampleRate, GetSequenceIDMap as GetSequenceIDMap, GetTilePrioritizer as GetTilePrioritizer, IsDefaultROIUsed as IsDefaultROIUsed, IsRenderNode as IsRenderNode, IsRenderROIAbsolute as IsRenderROIAbsolute, IsRerendering as IsRerendering, IsSceneGraphMaskEnabled as IsSceneGraphMaskEnabled, QueryRender as QueryRender, ResetRenderROI as ResetRenderROI, ResumeRender as ResumeRender, SetBuffer2DAutoLock as SetBuffer2DAutoLock, SetDiskCachingAllowed as SetDiskCachingAllowed, SetInteractiveSampleRate as SetInteractiveSampleRate, SetLiveRenderOpTreePath as SetLiveRenderOpTreePath, SetOverscanPadding as SetOverscanPadding, SetRenderIDPass as SetRenderIDPass, SetRenderMode as SetRenderMode, SetRenderROI as SetRenderROI, SetRenderROIAbsolute as SetRenderROIAbsolute, SetRenderRawROI as SetRenderRawROI, SetRenderUseROI as SetRenderUseROI, SetRenderViews as SetRenderViews, SetRenderViewsAutoUpdate as SetRenderViewsAutoUpdate, SetRerenderCamera as SetRerenderCamera, SetRerenderMode as SetRerenderMode, SetRerenderNodeName as SetRerenderNodeName, SetRerendering as SetRerendering, SetSampleRate as SetSampleRate, SetTilePrioritizer as SetTilePrioritizer, SuspendRender as SuspendRender, TriggerManualRender as TriggerManualRender, UpdateSequenceIDMap as UpdateSequenceIDMap
from PyUtilModule.RenderManager.RenderSettings import RenderingSettings as RenderingSettings
from PyUtilModule.RenderManager.RenderTriggers import DoesNodeTrigger2DRender as DoesNodeTrigger2DRender
from PyUtilModule.RenderManager.ResolutionTableUtils import GetTempResolutionTablePath as GetTempResolutionTablePath, SaveResolutionTables as SaveResolutionTables
from PyUtilModule.RenderManager.ScenegraphUtils import AddRenderSettingsToRecipe as AddRenderSettingsToRecipe
from typing import Set, Tuple

RENDERCAMERAPATH_VIEWER_BUILTIN: str
RENDERCAMERATYPES: tuple
RENDERCAMERATYPE_RENDERSETTINGS: int
RENDERCAMERATYPE_RENDERSETTINGS_LABEL: str
RENDERCAMERATYPE_SPECIFIC: int
RENDERCAMERATYPE_VIEWER: int
RENDERCAMERATYPE_VIEWER_LABEL: str
RENDERMODES: tuple
RENDERMODE_INTERACTIVE: int
RENDERMODE_LABELS: dict
RENDERMODE_OPTIONS: list
RENDERMODE_PENUP: int
RENDERMODE_PROCESS: int
TILE_PRIORITIZER_NONE: int
TILE_PRIORITIZER_SCANLINE: int
TILE_PRIORITIZER_SPIRAL: int



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
import collections
import enum
import typing
from UI4.FormMaster.ParameterPolicy import CreateParameterPolicy as CreateParameterPolicy
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from UI4.Util.AssetId import FormatExtraImageInfo as FormatExtraImageInfo, GetExtraImageInfo as GetExtraImageInfo
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class FileInItem(PyQt5.QtCore.QObject):
    updated: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, fileInNode, autoUpdate: bool = ...) -> None: ...
    @staticmethod
    def GetKeyFunction(column): ...
    def _FileInItem__emitUpdated(self, updatedColumns): ...
    def _FileInItem__getNodeIcon(self, viewed: bool = ..., edited: bool = ..., ignored: bool = ..., error: bool = ...): ...
    def _FileInItem__updateName(self): ...
    def _FileInItem__updatePathAndStatus(self): ...
    def _FileInItem__updateSuperToolMembership(self): ...
    def _FileInItem__updateVersion(self): ...
    def getData(self, column, role): ...
    def getIcon(self): ...
    def getName(self): ...
    def getNameKey(self): ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getPath(self): ...
    def getStatus(self): ...
    def getStatusKey(self): ...
    def getSuperToolNode(self): ...
    def getValuePolicy(self): ...
    def getVersion(self): ...
    def isStatusError(self): ...
    def setAutoUpdate(self, autoUpdate): ...
    def update(self): ...

class FileInPanel(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent) -> None: ...
    def _FileInPanel__autoUpdateCheckChanged(self, checkState): ...
    def _FileInPanel__loadBeginCB(self, eventType, eventID): ...
    def _FileInPanel__loadEndCB(self, eventType, eventID): ...
    def _FileInPanel__loadFileIn(self, fileInNode, load): ...
    def _FileInPanel__loadFileInBatch(self, fileInList): ...
    def _FileInPanel__nodeCreateCB(self, eventType, eventID, node: typing.Optional[NodegraphAPI.Node] = ..., nodeType: Incomplete | None = ..., nodeName: Incomplete | None = ...): ...
    def _FileInPanel__nodeDeleteCB(self, eventType, eventID, node: typing.Optional[NodegraphAPI.Node] = ..., oldName: Incomplete | None = ...): ...
    def _FileInPanel__prefChangeCB(self, args: Incomplete | None = ...): ...
    def _FileInPanel__setUpEvents(self, enabled): ...

class FileInTableModel(PyQt5.QtCore.QAbstractTableModel):
    class COLUMNS(enum.Enum):
        NAME: ClassVar[FileInTableModel.COLUMNS] = ...
        NODE: ClassVar[FileInTableModel.COLUMNS] = ...
        PATH: ClassVar[FileInTableModel.COLUMNS] = ...
        STATUS: ClassVar[FileInTableModel.COLUMNS] = ...
        VERSION: ClassVar[FileInTableModel.COLUMNS] = ...
        _member_map_: ClassVar[collections.OrderedDict] = ...
        _member_names_: ClassVar[list] = ...
        _member_type_: ClassVar[type[object]] = ...
        _value2member_map_: ClassVar[dict] = ...
        @classmethod
        def __init__(cls, value) -> None: ...
        def _generate_next_value_(self, name, start, count, last_values): ...
    dataChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _FileInTableModel__itemUpdated(self, item, columnSet): ...
    def addNode(self, fileInNode): ...
    def clear(self): ...
    def columnCount(self, parentIndex: Incomplete | None = ...): ...
    def data(self, modelIndex, role): ...
    def goToNode(self, modelIndex, edit: bool = ..., select: bool = ..., frame: bool = ...): ...
    def headerData(self, section, orientation, role): ...
    def removeNode(self, fileInNode): ...
    def rowCount(self, parentIndex: Incomplete | None = ...): ...
    def setAutoUpdate(self, autoUpdate): ...
    def sort(self, column, sortOrder): ...
    def update(self): ...

class FileInTableView(PyQt5.QtWidgets.QTableView):
    def __init__(self, parent) -> None: ...
    def _FileInTableView__indexClicked(self, modelIndex): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import CatalogAPI as CatalogAPI
import ConfigurationAPI_cmodule as Configuration
import KatanaResources as KatanaResources
import PyUtilModule as PyUtilModule
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import KatanaResources as ResourceFiles
import Utils as Utils
from typing import Set, Tuple

QuitState: object
_InterfaceIsBeingInitialized: bool

def InitializeInterface(options, args): ...
def IsInterfaceBeingInitialized() -> bool: ...
def IterativeInitializeInterface(app, options, splashScreen): ...
def Main(options, args): ...
def VerifyFontPreferences(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack.LayerStack
import QT4GLLayerStack.Util as Util
from QT4GLLayerStack.EventEaterLayer import EventEaterLayer as EventEaterLayer
from QT4GLLayerStack.LayerStack import Layer as Layer
from _typeshed import Incomplete
from typing import Set, Tuple

class ZoomAnimationLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, prevFocusLayer: Incomplete | None = ...) -> None: ...
    def _ZoomAnimationLayer__lerpSeq(self, aSeq, bSeq, x): ...
    def getEyeAndScaleFromBounds(self, targetVisibleArea): ...
    def zoomAndRemove(self, targetVisibleArea: Incomplete | None = ..., targetEyePoint: Incomplete | None = ..., targetViewScale: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtGui as QtGui
import UI4.Tabs
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def CreateNodeAtActiveConnection(layerStack: NodegraphWidget, nodeType: str) -> bool: ...
def FitBackdropAroundNodes(nodeGraphWidget: UI4.Tabs.NodegraphWidget, nodes: list, backdropNode: Incomplete | None = ..., padding: int = ...): ...
def UpdateShadingGroupConnection(port: NodegraphAPI.Port): ...
